diff --git a/src/BloatyNosy/App.config b/src/BloatyNosy/App.config
index 1c75772..a86c646 100644
--- a/src/BloatyNosy/App.config
+++ b/src/BloatyNosy/App.config
@@ -1,6 +1,6 @@
-
+
-
+
-
\ No newline at end of file
+
diff --git a/src/BloatyNosy/AppIcon.ico b/src/BloatyNosy/AppIcon.ico
index b1f72d9..c306a50 100644
Binary files a/src/BloatyNosy/AppIcon.ico and b/src/BloatyNosy/AppIcon.ico differ
diff --git a/src/BloatyNosy/AppIcon.png b/src/BloatyNosy/AppIcon.png
new file mode 100644
index 0000000..9cf302b
Binary files /dev/null and b/src/BloatyNosy/AppIcon.png differ
diff --git a/src/BloatyNosy/BloatyNosy.csproj b/src/BloatyNosy/BloatyNosy.csproj
index ffaf2a0..cd8969b 100644
--- a/src/BloatyNosy/BloatyNosy.csproj
+++ b/src/BloatyNosy/BloatyNosy.csproj
@@ -27,6 +27,7 @@
1.0.0.%2a
false
true
+
x64
@@ -78,7 +79,9 @@
+
+
@@ -90,13 +93,13 @@
+
-
@@ -106,7 +109,7 @@
-
+
diff --git a/src/BloatyNosy/Features/Apps/StoreApps.cs b/src/BloatyNosy/Features/Apps/StoreApps.cs
index 4c61b24..d3fba41 100644
--- a/src/BloatyNosy/Features/Apps/StoreApps.cs
+++ b/src/BloatyNosy/Features/Apps/StoreApps.cs
@@ -17,7 +17,7 @@ namespace Features.Feature.Apps
public override string Info()
{
- return "To remove specific apps use the BloatFinder app in the \"More Apps\" section or right click on this feature";
+ return "To remove specific apps use the AppyTrash app in the \"More Apps\" section or right click on this feature";
}
private void RemoveApps(string str)
diff --git a/src/BloatyNosy/Features/Apps/StoreEngine.cs b/src/BloatyNosy/Features/Apps/StoreEngine.cs
new file mode 100644
index 0000000..036d4c6
--- /dev/null
+++ b/src/BloatyNosy/Features/Apps/StoreEngine.cs
@@ -0,0 +1,74 @@
+using System.Collections.Generic;
+
+namespace BloatyNosy
+{
+ public static class BloatwareList
+ {
+ // Our Windows 11 bloatware list
+ public static IEnumerable GetList()
+ {
+ var apps = new List
+ {
+ "2FE3CB00.PICSART-PHOTOSTUDIO",
+ "4DF9E0F8.Netflix",
+ "5319275A.WhatsAppDesktop",
+ "9E2F88E3.TWITTER",
+ "NAVER.LINEwin8_8ptj331gd3tyt",
+ "SpotifyAB.SpotifyMusic",
+ "king.com.CandyCrushFriends",
+ "king.com.CandyCrushSaga",
+ "king.com.FarmHeroesSaga",
+ "22364Disney.ESPNBetaPWA",
+ "5A894077.McAfeeSecurity",
+ "AdobeSystemsIncorporated.AdobeCreativeCloudExpress",
+ "AmazonVideo.PrimeVideo",
+ "AppUp.IntelGraphicsExperience",
+ "B9ECED6F.ASUSPCAssistant",
+ "B9ECED6F.ScreenPadMaster",
+ "BytedancePte.Ltd.TikTok",
+ "Clipchamp.Clipchamp",
+ "DTSInc.DTSAudioProcess",
+ "AdobeSystemsIncorporated.AdobeLightroom",
+ "AdobeSystemsIncorporated.AdobePhotoshopExpress",
+ "Clipchamp.Clipchamp_yxz26nhyzhsrt",
+ "CorelCorporation.PaintShopPro",
+ "FACEBOOK.317180B0BB486",
+ "Facebook.InstagramBeta",
+ "AD2F1837.HPJumpStarts",
+ "AD2F1837.HPPCHardwareDiagnosticsWindows",
+ "AD2F1837.HPPowerManager",
+ "AD2F1837.HPPrivacySettings",
+ "AD2F1837.HPSupportAssistant",
+ "AD2F1837.HPSureShieldAI",
+ "AD2F1837.HPSystemInformation",
+ "AD2F1837.HPQuickDrop",
+ "AD2F1837.HPWorkWell",
+ "AD2F1837.myHP",
+ "AD2F1837.HPDesktopSupportUtilities",
+ "AD2F1837.HPQuickTouch",
+ "AD2F1837.HPEasyClean",
+ "AD2F1837.HPSystemInformation",
+ "Microsoft.549981C3F5F10",
+ "Microsoft.BingNews",
+ "Microsoft.BingWeather",
+ "Microsoft.GamingApp",
+ "Microsoft.Getstarted",
+ "Microsoft.Microsoft3DViewer",
+ "Microsoft.MicrosoftOfficeHub",
+ "Microsoft.MicrosoftSolitaireCollection",
+ "Microsoft.MicrosoftStickyNotes",
+ "Microsoft.MixedReality.Portal",
+ "Microsoft.Office.OneNote",
+ "Microsoft.OneDriveSync",
+ "Microsoft.OneConnect",
+ "Microsoft.People",
+ "Microsoft.Print3D",
+ "Microsoft.SkypeApp",
+ "Microsoft.Wallet",
+ "Microsoft.WindowsSoundRecorder"
+ };
+
+ return apps;
+ }
+ }
+}
\ No newline at end of file
diff --git a/src/BloatyNosy/Features/Apps/StoreHallOfShame.cs b/src/BloatyNosy/Features/Apps/StoreHallOfShame.cs
new file mode 100644
index 0000000..83fb228
--- /dev/null
+++ b/src/BloatyNosy/Features/Apps/StoreHallOfShame.cs
@@ -0,0 +1,27 @@
+using System.Collections.Generic;
+
+namespace BloatyNosy
+{
+ public static class BloatwareHallOfShame
+ {
+ // Our Windows 11 Hall Of Shame
+ public static IEnumerable GetList()
+ {
+ var apps = new List
+ {
+ "BytedancePte.Ltd.TikTok",
+ "Facebook.InstagramBeta",
+ "Microsoft.MicrosoftOfficeHub",
+ "Microsoft.MicrosoftSolitaireCollection",
+ "Microsoft.ZuneVideo",
+ "Microsoft.MixedReality.Portal",
+ "Microsoft.Getstarted",
+ "Microsoft.Office.OneNote",
+ "Microsoft.Print3D",
+ "Microsoft.People",
+ };
+
+ return apps;
+ }
+ }
+}
\ No newline at end of file
diff --git a/src/BloatyNosy/Features/Browser/GoogleChrome.cs b/src/BloatyNosy/Features/Browser/GoogleChrome.cs
index 72eb67d..0f0802a 100644
--- a/src/BloatyNosy/Features/Browser/GoogleChrome.cs
+++ b/src/BloatyNosy/Features/Browser/GoogleChrome.cs
@@ -53,7 +53,7 @@ namespace Features.Feature.Browser
try
{
Registry.LocalMachine.DeleteSubKeyTree(@"Software\Policies\Google\Chrome", false);
- logger.Log("- Google Chrome Telemetry has been enabled.");
+ logger.Log("+ Google Chrome Telemetry has been enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Browser/MicrosoftEdge.cs b/src/BloatyNosy/Features/Browser/MicrosoftEdge.cs
new file mode 100644
index 0000000..319c050
--- /dev/null
+++ b/src/BloatyNosy/Features/Browser/MicrosoftEdge.cs
@@ -0,0 +1,63 @@
+using BloatyNosy;
+using Microsoft.Win32;
+
+namespace Features.Feature.Browser
+{
+ internal class EdgeBingAIButton : FeatureBase
+ {
+ private static readonly ErrorHelper logger = ErrorHelper.Instance;
+
+ private const string keyName = @"HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\Edge";
+ private const int desiredValue = 0;
+
+ public override string ID()
+ {
+ return "[HIGH] Disable giant Bing search (AI chat) button in Edge Browser";
+ }
+
+ public override string Info()
+ {
+ return "";
+ }
+
+ public override bool CheckFeature()
+ {
+ return !(
+ RegistryHelper.IntEquals(keyName, "HubsSidebarEnabled", desiredValue)
+ );
+ }
+
+ public override bool DoFeature()
+ {
+ try
+ {
+ Registry.SetValue(keyName, "HubsSidebarEnabled", desiredValue, RegistryValueKind.DWord);
+
+ logger.Log("- Bing search (AI chat) button has been disabled.");
+ logger.Log(keyName);
+
+ return true;
+ }
+ catch
+ { }
+
+ return false;
+ }
+
+ public override bool UndoFeature()
+ {
+ try
+ {
+ var RegKey = Registry.LocalMachine.OpenSubKey(@"Software\Policies\Microsoft\Edge", true);
+ RegKey.DeleteValue("HubsSidebarEnabled");
+
+ logger.Log("+ Bing search (AI chat) button has been enabled.");
+ return true;
+ }
+ catch
+ { }
+
+ return false;
+ }
+ }
+}
\ No newline at end of file
diff --git a/src/BloatyNosy/Features/Browser/MozillaFirefox.cs b/src/BloatyNosy/Features/Browser/MozillaFirefox.cs
index 17511ac..1b4bcc1 100644
--- a/src/BloatyNosy/Features/Browser/MozillaFirefox.cs
+++ b/src/BloatyNosy/Features/Browser/MozillaFirefox.cs
@@ -51,7 +51,7 @@ namespace Features.Feature.Browser
try
{
Registry.LocalMachine.DeleteSubKeyTree(@"Policies\Mozilla\Firefox", false);
- logger.Log(" Mozilla Firefox Telemetry has been enabled.");
+ logger.Log("+ Mozilla Firefox Telemetry has been enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Desktop/AppsTheme.cs b/src/BloatyNosy/Features/Desktop/AppsTheme.cs
index 055030f..7f67969 100644
--- a/src/BloatyNosy/Features/Desktop/AppsTheme.cs
+++ b/src/BloatyNosy/Features/Desktop/AppsTheme.cs
@@ -51,7 +51,7 @@ namespace Features.Feature.Desktop
try
{
Registry.SetValue(keyName, "AppsUseLightTheme", "1", RegistryValueKind.DWord);
- logger.Log("- Apps light theme has been successfully enabled.");
+ logger.Log("+ Apps light theme has been successfully enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Desktop/SnapAssistFlyout.cs b/src/BloatyNosy/Features/Desktop/SnapAssistFlyout.cs
index 338c7d0..af2ca90 100644
--- a/src/BloatyNosy/Features/Desktop/SnapAssistFlyout.cs
+++ b/src/BloatyNosy/Features/Desktop/SnapAssistFlyout.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Desktop
try
{
Registry.SetValue(keyName, "EnableSnapAssistFlyout", 1, RegistryValueKind.DWord);
- logger.Log("- Snap Assist has been enabled.\nPlease restart your PC for the changes to take effect.");
+ logger.Log("+ Snap Assist has been enabled.\nPlease restart your PC for the changes to take effect.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Desktop/Stickers.cs b/src/BloatyNosy/Features/Desktop/Stickers.cs
index 852646c..7ac1506 100644
--- a/src/BloatyNosy/Features/Desktop/Stickers.cs
+++ b/src/BloatyNosy/Features/Desktop/Stickers.cs
@@ -48,7 +48,7 @@ namespace Features.Feature.Desktop
try
{
Registry.SetValue(keyName, "EnableStickers", "1", RegistryValueKind.DWord);
- logger.Log("- Desktop Sticker feature has been enabled again.");
+ logger.Log("+ Desktop Sticker feature has been enabled again.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Desktop/Transparency.cs b/src/BloatyNosy/Features/Desktop/Transparency.cs
index 85f35b4..9ca7366 100644
--- a/src/BloatyNosy/Features/Desktop/Transparency.cs
+++ b/src/BloatyNosy/Features/Desktop/Transparency.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Desktop
try
{
Registry.SetValue(keyName, "EnableTransparency", 1, RegistryValueKind.DWord);
- logger.Log("- Transparency effects has been enabled.");
+ logger.Log("+ Transparency effects has been enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Desktop/Widgets.cs b/src/BloatyNosy/Features/Desktop/Widgets.cs
index 5695594..a8c6583 100644
--- a/src/BloatyNosy/Features/Desktop/Widgets.cs
+++ b/src/BloatyNosy/Features/Desktop/Widgets.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Desktop
try
{
Registry.SetValue(keyName, "TaskbarDa", 1, RegistryValueKind.DWord);
- logger.Log("- Widgets has been enabled.");
+ logger.Log("+ Widgets has been enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Desktop/WidgetsR.cs b/src/BloatyNosy/Features/Desktop/WidgetsR.cs
index 6633932..b58ba9a 100644
--- a/src/BloatyNosy/Features/Desktop/WidgetsR.cs
+++ b/src/BloatyNosy/Features/Desktop/WidgetsR.cs
@@ -39,7 +39,7 @@ namespace Features.Feature.Desktop
using (var client = new WebClient())
{
logger.Log("- Uninstalling Widgets app");
- WindowsHelper.RunWT("winget uninstall \"windows web experience pack\"");
+ WindowsHelper.RunWT("winget uninstall \"windows web experience pack\" --silent");
logger.Log("Done.");
return true;
}
@@ -56,7 +56,7 @@ namespace Features.Feature.Desktop
{
using (var client = new WebClient())
{
- logger.Log("- Installing Widgets app...\nWe've opened the download link in the Microsoft Store.\nPlease install the package \"Windows Web Experience Pack\". ");
+ logger.Log("+ Installing Widgets app...\nWe've opened the download link in the Microsoft Store.\nPlease install the package \"Windows Web Experience Pack\". ");
Process.Start("ms-windows-store://pdp/?ProductId=9MSSGKG348SP");
return true;
diff --git a/src/BloatyNosy/Features/Desktop/WindowsTheme.cs b/src/BloatyNosy/Features/Desktop/WindowsTheme.cs
index 36f00f6..284d010 100644
--- a/src/BloatyNosy/Features/Desktop/WindowsTheme.cs
+++ b/src/BloatyNosy/Features/Desktop/WindowsTheme.cs
@@ -48,7 +48,7 @@ namespace Features.Feature.Desktop
try
{
Registry.SetValue(keyName, "SystemUsesLightTheme", "1", RegistryValueKind.DWord);
- logger.Log("- Windows light theme has been successfully enabled.");
+ logger.Log("+ Windows light theme has been successfully enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Explorer/FileExplorer.cs b/src/BloatyNosy/Features/Explorer/FileExplorer.cs
index 27556cd..bdbf7aa 100644
--- a/src/BloatyNosy/Features/Explorer/FileExplorer.cs
+++ b/src/BloatyNosy/Features/Explorer/FileExplorer.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Explorer
var RegKey = Registry.LocalMachine.OpenSubKey(@"Software\Microsoft\Windows\CurrentVersion\Shell Extensions\Blocked", true);
RegKey.DeleteValue("{e2bf9676-5f8f-435c-97eb-11607a5bedf7}");
- logger.Log("- Windows 10 File Explorer has been successfully disabled.\nRestart is required for the changes to take effect!");
+ logger.Log("+ Windows 10 File Explorer has been successfully disabled.\nRestart is required for the changes to take effect!");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Explorer/HiddenFileExt.cs b/src/BloatyNosy/Features/Explorer/HiddenFileExt.cs
index 3907375..bb374ab 100644
--- a/src/BloatyNosy/Features/Explorer/HiddenFileExt.cs
+++ b/src/BloatyNosy/Features/Explorer/HiddenFileExt.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Explorer
try
{
Registry.SetValue(keyName, "HideFileExt", 1, RegistryValueKind.DWord);
- logger.Log("- File name extensions are now hidden again.");
+ logger.Log("+ File name extensions are now hidden again.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Explorer/HiddenFileFolder.cs b/src/BloatyNosy/Features/Explorer/HiddenFileFolder.cs
index 83bcb18..0127db6 100644
--- a/src/BloatyNosy/Features/Explorer/HiddenFileFolder.cs
+++ b/src/BloatyNosy/Features/Explorer/HiddenFileFolder.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Explorer
try
{
Registry.SetValue(keyName, "Hidden", 2, RegistryValueKind.DWord);
- logger.Log("- Files, folders and drives are now hidden again.");
+ logger.Log("+ Files, folders and drives are now hidden again.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Gaming/GameDVR.cs b/src/BloatyNosy/Features/Gaming/GameDVR.cs
index 097291c..2210103 100644
--- a/src/BloatyNosy/Features/Gaming/GameDVR.cs
+++ b/src/BloatyNosy/Features/Gaming/GameDVR.cs
@@ -61,7 +61,7 @@ namespace Features.Feature.Gaming
Registry.SetValue(keyName, "GameDVR_FSEBehaviorMode", "0", RegistryValueKind.DWord);
Registry.SetValue(keyName2, "value", 1, RegistryValueKind.DWord);
- logger.Log("- Game DVR feature has been successfully enabled.");
+ logger.Log("+ Game DVR feature has been successfully enabled.");
logger.Log(keyName + Environment.NewLine + keyName2);
return true;
}
diff --git a/src/BloatyNosy/Features/Gaming/PowerThrottling.cs b/src/BloatyNosy/Features/Gaming/PowerThrottling.cs
index 74f33c9..0de44a1 100644
--- a/src/BloatyNosy/Features/Gaming/PowerThrottling.cs
+++ b/src/BloatyNosy/Features/Gaming/PowerThrottling.cs
@@ -52,7 +52,7 @@ namespace Features.Feature.Gaming
var RegKey = Registry.LocalMachine.OpenSubKey(@"SYSTEM\CurrentControlSet\Control\Power\PowerThrottling", true);
RegKey.DeleteValue("PowerThrottlingOff");
- logger.Log("- PowerThrottling has been successfully enabled.");
+ logger.Log("+ PowerThrottling has been successfully enabled.");
logger.Log(keyName);
return true;
}
diff --git a/src/BloatyNosy/Features/Gaming/VisualFX.cs b/src/BloatyNosy/Features/Gaming/VisualFX.cs
index e2eed81..26d19f5 100644
--- a/src/BloatyNosy/Features/Gaming/VisualFX.cs
+++ b/src/BloatyNosy/Features/Gaming/VisualFX.cs
@@ -51,7 +51,7 @@ namespace Features.Feature.Gaming
{
Registry.SetValue(keyName, "VisualFXSetting", 0, RegistryValueKind.DWord);
- logger.Log("- Visual effects has been set to default choosing Windows what's best for your computer.");
+ logger.Log("+ Visual effects has been set to default choosing Windows what's best for your computer.");
logger.Log(keyName);
return true;
}
diff --git a/src/BloatyNosy/Features/Privacy/Advertising.cs b/src/BloatyNosy/Features/Privacy/Advertising.cs
index d106b93..f6bcb42 100644
--- a/src/BloatyNosy/Features/Privacy/Advertising.cs
+++ b/src/BloatyNosy/Features/Privacy/Advertising.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Privacy
try
{
Registry.SetValue(keyName, "Enabled", 1, RegistryValueKind.DWord);
- logger.Log("- Advertising ID for Relevant Ads has been successfully enabled.");
+ logger.Log("+ Advertising ID for Relevant Ads has been successfully enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Privacy/AppsAutoInstall.cs b/src/BloatyNosy/Features/Privacy/AppsAutoInstall.cs
index cc87f01..8b91588 100644
--- a/src/BloatyNosy/Features/Privacy/AppsAutoInstall.cs
+++ b/src/BloatyNosy/Features/Privacy/AppsAutoInstall.cs
@@ -50,7 +50,7 @@ namespace Features.Feature.Privacy
try
{
Registry.SetValue(keyName, "SilentInstalledAppsEnabled", 1, RegistryValueKind.DWord);
- logger.Log("- Automatic Installation of apps has been successfully enabled.");
+ logger.Log("+ Automatic Installation of apps has been successfully enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Privacy/BackgroundApps.cs b/src/BloatyNosy/Features/Privacy/BackgroundApps.cs
new file mode 100644
index 0000000..107c06d
--- /dev/null
+++ b/src/BloatyNosy/Features/Privacy/BackgroundApps.cs
@@ -0,0 +1,61 @@
+using BloatyNosy;
+using Microsoft.Win32;
+using System;
+
+namespace Features.Feature.Privacy
+{
+ internal class BackgroundApps : FeatureBase
+ {
+ private static readonly ErrorHelper logger = ErrorHelper.Instance;
+
+ private const string keyName = @"HKEY_CURRENT_USER\Software\Microsoft\Windows\CurrentVersion\BackgroundAccessApplications";
+ private const int desiredValue = 1;
+
+ public override string ID()
+ {
+ return "[HIGH] Disable Apps running in background";
+ }
+
+ public override string Info()
+ {
+ return "";
+ }
+
+ public override bool CheckFeature()
+ {
+ return !(
+ RegistryHelper.IntEquals(keyName, "GlobalUserDisabled", desiredValue)
+ );
+ }
+
+ public override bool DoFeature()
+ {
+ try
+ {
+ Registry.SetValue(keyName, "GlobalUserDisabled", desiredValue, RegistryValueKind.DWord);
+
+ logger.Log("- App access to running in background has been successfully disabled.");
+ logger.Log(keyName);
+ return true;
+ }
+ catch
+ { }
+
+ return false;
+ }
+
+ public override bool UndoFeature()
+ {
+ try
+ {
+ Registry.SetValue(keyName, "GlobalUserDisabled", 0, RegistryValueKind.DWord);
+ logger.Log("- App access to running in background has been successfully enabled.");
+ return true;
+ }
+ catch
+ { }
+
+ return false;
+ }
+ }
+}
\ No newline at end of file
diff --git a/src/BloatyNosy/Features/Privacy/CompatibilityTelemetry.cs b/src/BloatyNosy/Features/Privacy/CompatibilityTelemetry.cs
index f965c2d..263e794 100644
--- a/src/BloatyNosy/Features/Privacy/CompatibilityTelemetry.cs
+++ b/src/BloatyNosy/Features/Privacy/CompatibilityTelemetry.cs
@@ -50,7 +50,7 @@ namespace Features.Feature.Privacy
var RegKey = Registry.LocalMachine.OpenSubKey(@"Software\Microsoft\Windows NT\CurrentVersion\Image File Execution Options\CompatTelRunner.exe", true);
RegKey.DeleteValue("Debugger");
- logger.Log("- Compatibility Telemetry has been successfully enabled.");
+ logger.Log("+ Compatibility Telemetry has been successfully enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Privacy/DiagnosticData.cs b/src/BloatyNosy/Features/Privacy/DiagnosticData.cs
index 6cfbcf6..0636612 100644
--- a/src/BloatyNosy/Features/Privacy/DiagnosticData.cs
+++ b/src/BloatyNosy/Features/Privacy/DiagnosticData.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Privacy
try
{
Registry.SetValue(keyName, "TailoredExperiencesWithDiagnosticDataEnabled", 1, RegistryValueKind.DWord);
- logger.Log("- Diagnostic data has been successfully enabled.");
+ logger.Log("+ Diagnostic data has been successfully enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Privacy/Feedback.cs b/src/BloatyNosy/Features/Privacy/Feedback.cs
index 4d2e31b..5c955af 100644
--- a/src/BloatyNosy/Features/Privacy/Feedback.cs
+++ b/src/BloatyNosy/Features/Privacy/Feedback.cs
@@ -55,7 +55,7 @@ namespace Features.Feature.Privacy
RegKey.DeleteValue("NumberOfSIUFInPeriod");
RegKey.DeleteValue("PeriodInNanoSeconds");
- logger.Log("- Feedback has been successfully enabled.");
+ logger.Log("+ Feedback has been successfully enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Privacy/LocationTracking.cs b/src/BloatyNosy/Features/Privacy/LocationTracking.cs
index f0fc875..0a8182c 100644
--- a/src/BloatyNosy/Features/Privacy/LocationTracking.cs
+++ b/src/BloatyNosy/Features/Privacy/LocationTracking.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Privacy
try
{
Registry.SetValue(keyName, "Value", "Allow", RegistryValueKind.String);
- logger.Log("- Location tracking info has been successfully enabled.");
+ logger.Log("+ Location tracking info has been successfully enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Privacy/SuggestedContent.cs b/src/BloatyNosy/Features/Privacy/SuggestedContent.cs
index c7fcbed..c497c22 100644
--- a/src/BloatyNosy/Features/Privacy/SuggestedContent.cs
+++ b/src/BloatyNosy/Features/Privacy/SuggestedContent.cs
@@ -58,7 +58,7 @@ namespace Features.Feature.Privacy
Registry.SetValue(keyName2, "SubscribedContent-353694Enabled", 1, RegistryValueKind.DWord);
Registry.SetValue(keyName3, "SubscribedContent-353696Enabled", 1, RegistryValueKind.DWord);
- logger.Log("- Suggested content in Settings app has been successfully enabled.");
+ logger.Log("+ Suggested content in Settings app has been successfully enabled.");
logger.Log(keyName + Environment.NewLine + keyName2 + Environment.NewLine + keyName3);
return true;
}
diff --git a/src/BloatyNosy/Features/Privacy/TailoredExperiences.cs b/src/BloatyNosy/Features/Privacy/TailoredExperiences.cs
index 0191baf..eb35911 100644
--- a/src/BloatyNosy/Features/Privacy/TailoredExperiences.cs
+++ b/src/BloatyNosy/Features/Privacy/TailoredExperiences.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Privacy
try
{
Registry.SetValue(keyName, "TailoredExperiencesWithDiagnosticDataEnabled", 1, RegistryValueKind.DWord);
- logger.Log("- Tailored experiences has been successfully enabled.");
+ logger.Log("+ Tailored experiences has been successfully enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Privacy/Telemetry.cs b/src/BloatyNosy/Features/Privacy/Telemetry.cs
index a0f28b5..b23ab21 100644
--- a/src/BloatyNosy/Features/Privacy/Telemetry.cs
+++ b/src/BloatyNosy/Features/Privacy/Telemetry.cs
@@ -70,7 +70,7 @@ namespace Features.Feature.Privacy
WindowsHelper.EnableService("DiagTrack");
WindowsHelper.EnableService("dmwappushservice");
- logger.Log("- Connected User Experiences and Telemetry has been successfully enabled.");
+ logger.Log("+ Connected User Experiences and Telemetry has been successfully enabled.");
logger.Log(dataCollection + Environment.NewLine + diagTrack + Environment.NewLine + dmwappushservice);
return true;
}
diff --git a/src/BloatyNosy/Features/Privacy/WindowsTips.cs b/src/BloatyNosy/Features/Privacy/WindowsTips.cs
index bc41067..30be17f 100644
--- a/src/BloatyNosy/Features/Privacy/WindowsTips.cs
+++ b/src/BloatyNosy/Features/Privacy/WindowsTips.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Privacy
try
{
Registry.SetValue(keyName, "SubscribedContent-338393Enabled", 1, RegistryValueKind.DWord);
- logger.Log("- Windows 11 tips has been successfully enabled.");
+ logger.Log("+ Windows 11 tips has been successfully enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Recommendation/EnableWSL.cs b/src/BloatyNosy/Features/Recommendation/EnableWSL.cs
index b41507c..af79de8 100644
--- a/src/BloatyNosy/Features/Recommendation/EnableWSL.cs
+++ b/src/BloatyNosy/Features/Recommendation/EnableWSL.cs
@@ -48,7 +48,7 @@ namespace Features.Feature.Recommendation
powerShell.AddScript(script);
powerShell.Invoke();
- logger.Log("- Microsoft Windows Subsystem for Linux has been successfully enabled.");
+ logger.Log("+ Microsoft Windows Subsystem for Linux has been successfully enabled.");
return true;
}
diff --git a/src/BloatyNosy/Features/System/FaxPrinter.cs b/src/BloatyNosy/Features/System/FaxPrinter.cs
index 35f2062..1bcae2a 100644
--- a/src/BloatyNosy/Features/System/FaxPrinter.cs
+++ b/src/BloatyNosy/Features/System/FaxPrinter.cs
@@ -44,7 +44,7 @@ namespace Features.Feature.System
public override bool UndoFeature()
{
- logger.Log("- Fax printer can not be installed.");
+ logger.Log("= Fax printer can not be installed.");
return false;
}
}
diff --git a/src/BloatyNosy/Features/System/FullContextMenus.cs b/src/BloatyNosy/Features/System/FullContextMenus.cs
index c5c717b..b30424d 100644
--- a/src/BloatyNosy/Features/System/FullContextMenus.cs
+++ b/src/BloatyNosy/Features/System/FullContextMenus.cs
@@ -48,7 +48,7 @@ namespace Features.Feature.System
try
{
Registry.CurrentUser.DeleteSubKeyTree(@"Software\Classes\CLSID\{86ca1aa0-34aa-4e8b-a509-50c905bae2a2}", false);
-
+ logger.Log("+ Truncated context menus has been enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/System/OneDriveR.cs b/src/BloatyNosy/Features/System/OneDriveR.cs
index e9a27f3..f93fd75 100644
--- a/src/BloatyNosy/Features/System/OneDriveR.cs
+++ b/src/BloatyNosy/Features/System/OneDriveR.cs
@@ -66,7 +66,7 @@ namespace Features.Feature.System
{
using (var client = new WebClient())
{
- logger.Log("We've opened the download link in your Browser.\n\nPlease install the package \"OneDrive\". ");
+ logger.Log("= We've opened the download link in your Browser.\n\nPlease install the package \"OneDrive\". ");
Process.Start("https://www.microsoft.com/microsoft-365/onedrive/download");
return true;
diff --git a/src/BloatyNosy/Features/System/RemoveW11Watermark.cs b/src/BloatyNosy/Features/System/RemoveW11Watermark.cs
index 7de1a4c..c41e8ee 100644
--- a/src/BloatyNosy/Features/System/RemoveW11Watermark.cs
+++ b/src/BloatyNosy/Features/System/RemoveW11Watermark.cs
@@ -50,7 +50,7 @@ namespace Features.Feature.System
var RegKey = Registry.CurrentUser.OpenSubKey(@"Control Panel\UnsupportedHardwareNotificationCache", true);
RegKey.DeleteValue("SV2");
- logger.Log("- Watermark has been enabled again.");
+ logger.Log("+ Watermark has been enabled again.");
return true;
}
diff --git a/src/BloatyNosy/Features/System/TPMCheck.cs b/src/BloatyNosy/Features/System/TPMCheck.cs
index e5b8023..5a984f7 100644
--- a/src/BloatyNosy/Features/System/TPMCheck.cs
+++ b/src/BloatyNosy/Features/System/TPMCheck.cs
@@ -67,7 +67,7 @@ namespace Features.Feature.System
Registry.LocalMachine.OpenSubKey(@"SYSTEM\Setup\LabConfig", true).DeleteValue("BypassCPUCheck", false);
Registry.SetValue(@"HKEY_LOCAL_MACHINE\SYSTEM\Setup\MoSetup", "AllowUpgradesWithUnsupportedTPMOrCPU", "0", RegistryValueKind.DWord);
- logger.Log("- TPM 2.0 Check has been enabled again.");
+ logger.Log("+ TPM 2.0 Check has been enabled again.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/System/TeamsAutostart.cs b/src/BloatyNosy/Features/System/TeamsAutostart.cs
index 9634864..024562f 100644
--- a/src/BloatyNosy/Features/System/TeamsAutostart.cs
+++ b/src/BloatyNosy/Features/System/TeamsAutostart.cs
@@ -59,7 +59,7 @@ namespace Features.Feature.System
{
Registry.SetValue(keyName, "com.squirrel.Teams.Teams", desiredValue, RegistryValueKind.String);
- logger.Log("- Teams AutoStart has been enabled again.");
+ logger.Log("+ Teams AutoStart has been enabled again.");
logger.Log(keyName);
return true;
}
diff --git a/src/BloatyNosy/Features/System/XPSWriter.cs b/src/BloatyNosy/Features/System/XPSWriter.cs
index 4cfc27d..0fbdc41 100644
--- a/src/BloatyNosy/Features/System/XPSWriter.cs
+++ b/src/BloatyNosy/Features/System/XPSWriter.cs
@@ -50,7 +50,7 @@ namespace Features.Feature.System
if (powerShell.Streams.Error.Count > 0)
{
- logger.Log("XPS Documents Writer not found.");
+ logger.Log("= XPS Documents Writer not found.");
return false;
}
@@ -67,11 +67,11 @@ namespace Features.Feature.System
var results = powerShell.Invoke();
if (powerShell.Streams.Error.Count > 0)
{
- logger.Log("XPS Documents Writer could not be installed.");
+ logger.Log("- XPS Documents Writer could not be installed.");
return false;
}
- logger.Log("- XPS Documents Writer has been successfully installed.");
+ logger.Log("+ XPS Documents Writer has been successfully installed.");
return true;
}
}
diff --git a/src/BloatyNosy/Features/Taskbar/MostUsedApps.cs b/src/BloatyNosy/Features/Taskbar/MostUsedApps.cs
index 4756305..b0ade45 100644
--- a/src/BloatyNosy/Features/Taskbar/MostUsedApps.cs
+++ b/src/BloatyNosy/Features/Taskbar/MostUsedApps.cs
@@ -51,7 +51,7 @@ namespace Features.Feature.Taskbar
var RegKey = Registry.LocalMachine.OpenSubKey(@"SOFTWARE\Policies\Microsoft\Windows\Explorer", true);
RegKey.DeleteValue("ShowOrHideMostUsedApps");
- logger.Log("- Most Used Apps has been set to default behavior.");
+ logger.Log("+ Most Used Apps has been set to default behavior.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Taskbar/StartmenuLayout.cs b/src/BloatyNosy/Features/Taskbar/StartmenuLayout.cs
index ab62e6a..c1be9d0 100644
--- a/src/BloatyNosy/Features/Taskbar/StartmenuLayout.cs
+++ b/src/BloatyNosy/Features/Taskbar/StartmenuLayout.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Taskbar
try
{
Registry.SetValue(keyName, "Start_Layout", 0, RegistryValueKind.DWord);
- logger.Log("- Showing more Pins on Start menu has been enabled.");
+ logger.Log("+ Showing more Pins on Start menu has been enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Taskbar/TaskView.cs b/src/BloatyNosy/Features/Taskbar/TaskView.cs
index bda900f..96988a0 100644
--- a/src/BloatyNosy/Features/Taskbar/TaskView.cs
+++ b/src/BloatyNosy/Features/Taskbar/TaskView.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Taskbar
try
{
Registry.SetValue(keyName, "ShowTaskViewButton", 1, RegistryValueKind.DWord);
- logger.Log("- Task view button has been enabled.");
+ logger.Log("+ Task view button has been enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Taskbar/TaskbarChat.cs b/src/BloatyNosy/Features/Taskbar/TaskbarChat.cs
index c263692..c5f0812 100644
--- a/src/BloatyNosy/Features/Taskbar/TaskbarChat.cs
+++ b/src/BloatyNosy/Features/Taskbar/TaskbarChat.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Taskbar
try
{
Registry.SetValue(keyName, "TaskbarMn", 1, RegistryValueKind.DWord);
- logger.Log("- Chat icon has been enabled.");
+ logger.Log("+ Chat icon has been enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Features/Taskbar/TaskbarSearch.cs b/src/BloatyNosy/Features/Taskbar/TaskbarSearch.cs
index 737b8d4..f11925a 100644
--- a/src/BloatyNosy/Features/Taskbar/TaskbarSearch.cs
+++ b/src/BloatyNosy/Features/Taskbar/TaskbarSearch.cs
@@ -49,7 +49,7 @@ namespace Features.Feature.Taskbar
try
{
Registry.SetValue(keyName, "SearchboxTaskbarMode", 1, RegistryValueKind.DWord);
- logger.Log("- Search icon has been enabled.");
+ logger.Log("+ Search icon has been enabled.");
return true;
}
catch
diff --git a/src/BloatyNosy/Helpers/HelperTool.cs b/src/BloatyNosy/Helpers/HelperTool.cs
index 430f0ce..ff3bc05 100644
--- a/src/BloatyNosy/Helpers/HelperTool.cs
+++ b/src/BloatyNosy/Helpers/HelperTool.cs
@@ -29,6 +29,7 @@ namespace HelperTool
{
public static string SysDir = Path.GetPathRoot(Environment.SystemDirectory);
public static string LocalAppDataDir = Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData);
+ public static string ProgramFiles = Environment.GetFolderPath(Environment.SpecialFolder.ProgramFiles);
public static string ShellWT = LocalAppDataDir +
@"\Microsoft\WindowsApps\wt.exe";
diff --git a/src/BloatyNosy/MainForm.Designer.cs b/src/BloatyNosy/MainForm.Designer.cs
index ee85dea..05c6804 100644
--- a/src/BloatyNosy/MainForm.Designer.cs
+++ b/src/BloatyNosy/MainForm.Designer.cs
@@ -31,7 +31,7 @@
this.components = new System.ComponentModel.Container();
this.pnlForm = new System.Windows.Forms.Panel();
this.pnlMain = new System.Windows.Forms.Panel();
- this.lnkGitHubRepo = new System.Windows.Forms.LinkLabel();
+ this.lblOS = new System.Windows.Forms.Label();
this.lblAppOptionsFix = new System.Windows.Forms.Label();
this.lnkRunSetup = new System.Windows.Forms.LinkLabel();
this.btnAppOptions = new System.Windows.Forms.Button();
@@ -44,13 +44,19 @@
this.lblTools = new System.Windows.Forms.Label();
this.cmbTools = new System.Windows.Forms.ComboBox();
this.lblHeader = new System.Windows.Forms.Label();
- this.tvwFeatures = new System.Windows.Forms.TreeView();
this.rtbLog = new System.Windows.Forms.RichTextBox();
+ this.tvwFeatures = new System.Windows.Forms.TreeView();
this.contextKebapMenu = new System.Windows.Forms.ContextMenuStrip(this.components);
+ this.textHeader = new System.Windows.Forms.ToolStripTextBox();
this.menuAdvanced = new System.Windows.Forms.ToolStripMenuItem();
- this.menuIgnoreLowLevelP = new System.Windows.Forms.ToolStripMenuItem();
- this.menuImportProfile = new System.Windows.Forms.ToolStripMenuItem();
+ this.menuIgnoreLowLevelI = new System.Windows.Forms.ToolStripMenuItem();
+ this.cbProfiles = new System.Windows.Forms.ToolStripComboBox();
+ this.menuLoadProfile = new System.Windows.Forms.ToolStripMenuItem();
this.menuExportProfile = new System.Windows.Forms.ToolStripMenuItem();
+ this.toolStripSeparator1 = new System.Windows.Forms.ToolStripSeparator();
+ this.textExplanation = new System.Windows.Forms.ToolStripTextBox();
+ this.textExplanationIssue = new System.Windows.Forms.ToolStripTextBox();
+ this.textExplanationOK = new System.Windows.Forms.ToolStripTextBox();
this.contextAppMenu = new System.Windows.Forms.ContextMenuStrip(this.components);
this.menuFix = new System.Windows.Forms.ToolStripMenuItem();
this.menuFixInfo = new System.Windows.Forms.ToolStripTextBox();
@@ -72,13 +78,13 @@
this.pnlForm.Dock = System.Windows.Forms.DockStyle.Fill;
this.pnlForm.Location = new System.Drawing.Point(0, 0);
this.pnlForm.Name = "pnlForm";
- this.pnlForm.Size = new System.Drawing.Size(1019, 801);
+ this.pnlForm.Size = new System.Drawing.Size(430, 616);
this.pnlForm.TabIndex = 0;
//
// pnlMain
//
this.pnlMain.AutoScroll = true;
- this.pnlMain.Controls.Add(this.lnkGitHubRepo);
+ this.pnlMain.Controls.Add(this.lblOS);
this.pnlMain.Controls.Add(this.lblAppOptionsFix);
this.pnlMain.Controls.Add(this.lnkRunSetup);
this.pnlMain.Controls.Add(this.btnAppOptions);
@@ -91,27 +97,26 @@
this.pnlMain.Controls.Add(this.lblTools);
this.pnlMain.Controls.Add(this.cmbTools);
this.pnlMain.Controls.Add(this.lblHeader);
- this.pnlMain.Controls.Add(this.tvwFeatures);
this.pnlMain.Controls.Add(this.rtbLog);
+ this.pnlMain.Controls.Add(this.tvwFeatures);
this.pnlMain.Dock = System.Windows.Forms.DockStyle.Fill;
this.pnlMain.Location = new System.Drawing.Point(0, 0);
this.pnlMain.Name = "pnlMain";
- this.pnlMain.Size = new System.Drawing.Size(1019, 801);
+ this.pnlMain.Size = new System.Drawing.Size(430, 616);
this.pnlMain.TabIndex = 0;
//
- // lnkGitHubRepo
+ // lblOS
//
- this.lnkGitHubRepo.AutoEllipsis = true;
- this.lnkGitHubRepo.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 12.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
- this.lnkGitHubRepo.LinkBehavior = System.Windows.Forms.LinkBehavior.HoverUnderline;
- this.lnkGitHubRepo.LinkColor = System.Drawing.Color.HotPink;
- this.lnkGitHubRepo.Location = new System.Drawing.Point(209, 112);
- this.lnkGitHubRepo.Name = "lnkGitHubRepo";
- this.lnkGitHubRepo.Size = new System.Drawing.Size(113, 23);
- this.lnkGitHubRepo.TabIndex = 181;
- this.lnkGitHubRepo.TabStop = true;
- this.lnkGitHubRepo.Text = "Bloaty && Nosy";
- this.lnkGitHubRepo.LinkClicked += new System.Windows.Forms.LinkLabelLinkClickedEventHandler(this.lnkGitHubRepo_LinkClicked);
+ this.lblOS.AutoEllipsis = true;
+ this.lblOS.BackColor = System.Drawing.Color.MediumVioletRed;
+ this.lblOS.Font = new System.Drawing.Font("Segoe UI Variable Display", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.lblOS.ForeColor = System.Drawing.Color.White;
+ this.lblOS.Location = new System.Drawing.Point(119, 220);
+ this.lblOS.Name = "lblOS";
+ this.lblOS.Size = new System.Drawing.Size(177, 16);
+ this.lblOS.TabIndex = 181;
+ this.lblOS.Text = "Windows 11 ";
+ this.lblOS.Click += new System.EventHandler(this.lblOS_Click);
//
// lblAppOptionsFix
//
@@ -119,7 +124,7 @@
this.lblAppOptionsFix.BackColor = System.Drawing.Color.MediumVioletRed;
this.lblAppOptionsFix.Font = new System.Drawing.Font("Segoe UI Variable Text Semibold", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.lblAppOptionsFix.ForeColor = System.Drawing.Color.White;
- this.lblAppOptionsFix.Location = new System.Drawing.Point(360, 225);
+ this.lblAppOptionsFix.Location = new System.Drawing.Point(312, 219);
this.lblAppOptionsFix.Name = "lblAppOptionsFix";
this.lblAppOptionsFix.Size = new System.Drawing.Size(25, 17);
this.lblAppOptionsFix.TabIndex = 180;
@@ -131,7 +136,7 @@
this.lnkRunSetup.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
this.lnkRunSetup.AutoSize = true;
this.lnkRunSetup.Font = new System.Drawing.Font("Segoe UI Variable Text", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
- this.lnkRunSetup.Location = new System.Drawing.Point(704, 764);
+ this.lnkRunSetup.Location = new System.Drawing.Point(70, 597);
this.lnkRunSetup.Name = "lnkRunSetup";
this.lnkRunSetup.Size = new System.Drawing.Size(229, 15);
this.lnkRunSetup.TabIndex = 179;
@@ -146,7 +151,7 @@
this.btnAppOptions.FlatAppearance.BorderSize = 0;
this.btnAppOptions.Font = new System.Drawing.Font("Segoe Fluent Icons", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.btnAppOptions.ForeColor = System.Drawing.Color.White;
- this.btnAppOptions.Location = new System.Drawing.Point(350, 213);
+ this.btnAppOptions.Location = new System.Drawing.Point(302, 207);
this.btnAppOptions.Name = "btnAppOptions";
this.btnAppOptions.Padding = new System.Windows.Forms.Padding(0, 0, 5, 0);
this.btnAppOptions.Size = new System.Drawing.Size(62, 42);
@@ -164,7 +169,7 @@
this.btnSettings.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
this.btnSettings.Font = new System.Drawing.Font("Segoe Fluent Icons", 14.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.btnSettings.ForeColor = System.Drawing.Color.MediumVioletRed;
- this.btnSettings.Location = new System.Drawing.Point(965, 751);
+ this.btnSettings.Location = new System.Drawing.Point(376, 554);
this.btnSettings.Name = "btnSettings";
this.btnSettings.Size = new System.Drawing.Size(42, 38);
this.btnSettings.TabIndex = 177;
@@ -174,16 +179,14 @@
//
// label1
//
- this.label1.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
- | System.Windows.Forms.AnchorStyles.Right)));
- this.label1.AutoEllipsis = true;
- this.label1.Font = new System.Drawing.Font("Segoe UI Variable Text Semibold", 21.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
- this.label1.Location = new System.Drawing.Point(47, 49);
+ this.label1.AutoSize = true;
+ this.label1.Font = new System.Drawing.Font("Segoe UI Variable Text Semibold", 20.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.label1.Location = new System.Drawing.Point(13, 50);
this.label1.Name = "label1";
- this.label1.Size = new System.Drawing.Size(575, 43);
+ this.label1.Size = new System.Drawing.Size(370, 36);
this.label1.TabIndex = 176;
- this.label1.Text = "No more draw backs of upgrading to Windows 11 ";
- this.label1.TextAlign = System.Drawing.ContentAlignment.BottomCenter;
+ this.label1.Text = "Boost your PC\'s performance";
+ this.label1.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
//
// btnKebapMenu
//
@@ -193,9 +196,9 @@
this.btnKebapMenu.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
this.btnKebapMenu.Font = new System.Drawing.Font("Segoe Fluent Icons", 21.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.btnKebapMenu.ForeColor = System.Drawing.Color.FromArgb(((int)(((byte)(64)))), ((int)(((byte)(64)))), ((int)(((byte)(64)))));
- this.btnKebapMenu.Location = new System.Drawing.Point(970, 0);
+ this.btnKebapMenu.Location = new System.Drawing.Point(381, 0);
this.btnKebapMenu.Name = "btnKebapMenu";
- this.btnKebapMenu.Size = new System.Drawing.Size(42, 38);
+ this.btnKebapMenu.Size = new System.Drawing.Size(42, 47);
this.btnKebapMenu.TabIndex = 175;
this.btnKebapMenu.Text = "...";
this.btnKebapMenu.TextAlign = System.Drawing.ContentAlignment.TopCenter;
@@ -207,13 +210,15 @@
this.btnAnalyze.AutoEllipsis = true;
this.btnAnalyze.BackColor = System.Drawing.Color.MediumVioletRed;
this.btnAnalyze.FlatAppearance.BorderSize = 0;
- this.btnAnalyze.Font = new System.Drawing.Font("Segoe UI Variable Text Semibold", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.btnAnalyze.Font = new System.Drawing.Font("Segoe UI Variable Text Semibold", 12F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.btnAnalyze.ForeColor = System.Drawing.Color.White;
- this.btnAnalyze.Location = new System.Drawing.Point(71, 213);
+ this.btnAnalyze.Location = new System.Drawing.Point(23, 207);
this.btnAnalyze.Name = "btnAnalyze";
+ this.btnAnalyze.Padding = new System.Windows.Forms.Padding(20, 0, 0, 0);
this.btnAnalyze.Size = new System.Drawing.Size(286, 42);
this.btnAnalyze.TabIndex = 27;
- this.btnAnalyze.Text = "Analyze Windows 11 ";
+ this.btnAnalyze.Text = "Analyze ";
+ this.btnAnalyze.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
this.btnAnalyze.UseVisualStyleBackColor = false;
this.btnAnalyze.Click += new System.EventHandler(this.btnAnalyze_Click);
//
@@ -222,15 +227,14 @@
this.lnkSubHeader.ActiveLinkColor = System.Drawing.Color.MediumVioletRed;
this.lnkSubHeader.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)
| System.Windows.Forms.AnchorStyles.Right)));
- this.lnkSubHeader.AutoEllipsis = true;
this.lnkSubHeader.Font = new System.Drawing.Font("Segoe UI Variable Text Semibold", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.lnkSubHeader.ForeColor = System.Drawing.Color.Black;
this.lnkSubHeader.ImeMode = System.Windows.Forms.ImeMode.NoControl;
this.lnkSubHeader.LinkBehavior = System.Windows.Forms.LinkBehavior.HoverUnderline;
this.lnkSubHeader.LinkColor = System.Drawing.Color.FromArgb(((int)(((byte)(64)))), ((int)(((byte)(64)))), ((int)(((byte)(64)))));
- this.lnkSubHeader.Location = new System.Drawing.Point(71, 679);
+ this.lnkSubHeader.Location = new System.Drawing.Point(12, 494);
this.lnkSubHeader.Name = "lnkSubHeader";
- this.lnkSubHeader.Size = new System.Drawing.Size(795, 18);
+ this.lnkSubHeader.Size = new System.Drawing.Size(400, 38);
this.lnkSubHeader.TabIndex = 171;
this.lnkSubHeader.LinkClicked += new System.Windows.Forms.LinkLabelLinkClickedEventHandler(this.lnkSubHeader_LinkClicked);
//
@@ -238,9 +242,9 @@
//
this.progress.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
| System.Windows.Forms.AnchorStyles.Right)));
- this.progress.Location = new System.Drawing.Point(72, 285);
+ this.progress.Location = new System.Drawing.Point(9, 285);
this.progress.Name = "progress";
- this.progress.Size = new System.Drawing.Size(856, 5);
+ this.progress.Size = new System.Drawing.Size(409, 5);
this.progress.TabIndex = 166;
this.progress.Visible = false;
//
@@ -250,7 +254,7 @@
this.lblTools.AutoSize = true;
this.lblTools.Font = new System.Drawing.Font("Segoe UI Variable Text Semibold", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.lblTools.ForeColor = System.Drawing.Color.DeepPink;
- this.lblTools.Location = new System.Drawing.Point(32, 758);
+ this.lblTools.Location = new System.Drawing.Point(32, 561);
this.lblTools.Name = "lblTools";
this.lblTools.Size = new System.Drawing.Size(35, 15);
this.lblTools.TabIndex = 25;
@@ -267,7 +271,7 @@
this.cmbTools.FormattingEnabled = true;
this.cmbTools.IntegralHeight = false;
this.cmbTools.ItemHeight = 21;
- this.cmbTools.Location = new System.Drawing.Point(75, 750);
+ this.cmbTools.Location = new System.Drawing.Point(75, 553);
this.cmbTools.Name = "cmbTools";
this.cmbTools.Size = new System.Drawing.Size(150, 29);
this.cmbTools.TabIndex = 19;
@@ -278,15 +282,35 @@
this.lblHeader.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
| System.Windows.Forms.AnchorStyles.Right)));
this.lblHeader.AutoEllipsis = true;
- this.lblHeader.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 12.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.lblHeader.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 11.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.lblHeader.ForeColor = System.Drawing.Color.FromArgb(((int)(((byte)(64)))), ((int)(((byte)(64)))), ((int)(((byte)(64)))));
- this.lblHeader.Location = new System.Drawing.Point(69, 112);
+ this.lblHeader.Location = new System.Drawing.Point(18, 112);
this.lblHeader.Name = "lblHeader";
- this.lblHeader.Size = new System.Drawing.Size(843, 59);
+ this.lblHeader.Size = new System.Drawing.Size(346, 70);
this.lblHeader.TabIndex = 16;
- this.lblHeader.Text = "Windows 11 is too and has some annoying features that just" +
- " need to go.\r\nThis app will scan your system and inform you which features it li" +
- "kes or dislikes in your configuration.";
+ this.lblHeader.Text = "Windows 11 is too bloaty && nosy and has some annoying features that just need to" +
+ " go. This app will scan your system and inform you which features it likes or di" +
+ "slikes in your configuration.";
+ //
+ // rtbLog
+ //
+ this.rtbLog.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
+ | System.Windows.Forms.AnchorStyles.Left)
+ | System.Windows.Forms.AnchorStyles.Right)));
+ this.rtbLog.BackColor = System.Drawing.Color.White;
+ this.rtbLog.BorderStyle = System.Windows.Forms.BorderStyle.None;
+ this.rtbLog.Cursor = System.Windows.Forms.Cursors.IBeam;
+ this.rtbLog.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.rtbLog.ForeColor = System.Drawing.Color.FromArgb(((int)(((byte)(64)))), ((int)(((byte)(64)))), ((int)(((byte)(64)))));
+ this.rtbLog.HideSelection = false;
+ this.rtbLog.Location = new System.Drawing.Point(9, 296);
+ this.rtbLog.Name = "rtbLog";
+ this.rtbLog.ReadOnly = true;
+ this.rtbLog.Size = new System.Drawing.Size(414, 175);
+ this.rtbLog.TabIndex = 138;
+ this.rtbLog.Text = "";
+ this.rtbLog.Visible = false;
+ this.rtbLog.LinkClicked += new System.Windows.Forms.LinkClickedEventHandler(this.richLog_LinkClicked);
//
// tvwFeatures
//
@@ -301,82 +325,129 @@
this.tvwFeatures.FullRowSelect = true;
this.tvwFeatures.ItemHeight = 30;
this.tvwFeatures.LineColor = System.Drawing.Color.HotPink;
- this.tvwFeatures.Location = new System.Drawing.Point(72, 305);
+ this.tvwFeatures.Location = new System.Drawing.Point(9, 296);
this.tvwFeatures.Name = "tvwFeatures";
this.tvwFeatures.ShowLines = false;
this.tvwFeatures.ShowNodeToolTips = true;
this.tvwFeatures.ShowRootLines = false;
- this.tvwFeatures.Size = new System.Drawing.Size(858, 360);
+ this.tvwFeatures.Size = new System.Drawing.Size(414, 175);
this.tvwFeatures.TabIndex = 168;
this.tvwFeatures.Visible = false;
this.tvwFeatures.AfterCheck += new System.Windows.Forms.TreeViewEventHandler(this.treeFeatures_AfterCheck);
this.tvwFeatures.MouseUp += new System.Windows.Forms.MouseEventHandler(this.tvwFeatures_MouseUp);
//
- // rtbLog
- //
- this.rtbLog.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
- | System.Windows.Forms.AnchorStyles.Left)
- | System.Windows.Forms.AnchorStyles.Right)));
- this.rtbLog.BackColor = System.Drawing.Color.White;
- this.rtbLog.BorderStyle = System.Windows.Forms.BorderStyle.None;
- this.rtbLog.Cursor = System.Windows.Forms.Cursors.IBeam;
- this.rtbLog.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
- this.rtbLog.ForeColor = System.Drawing.Color.FromArgb(((int)(((byte)(64)))), ((int)(((byte)(64)))), ((int)(((byte)(64)))));
- this.rtbLog.HideSelection = false;
- this.rtbLog.Location = new System.Drawing.Point(72, 305);
- this.rtbLog.Name = "rtbLog";
- this.rtbLog.ReadOnly = true;
- this.rtbLog.Size = new System.Drawing.Size(861, 360);
- this.rtbLog.TabIndex = 138;
- this.rtbLog.Text = "";
- this.rtbLog.Visible = false;
- this.rtbLog.LinkClicked += new System.Windows.Forms.LinkClickedEventHandler(this.richLog_LinkClicked);
- //
// contextKebapMenu
//
- this.contextKebapMenu.BackColor = System.Drawing.SystemColors.Control;
+ this.contextKebapMenu.BackColor = System.Drawing.Color.White;
this.contextKebapMenu.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 12F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.contextKebapMenu.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
+ this.textHeader,
this.menuAdvanced,
- this.menuIgnoreLowLevelP,
- this.menuImportProfile,
- this.menuExportProfile});
+ this.menuIgnoreLowLevelI,
+ this.cbProfiles,
+ this.menuLoadProfile,
+ this.menuExportProfile,
+ this.toolStripSeparator1,
+ this.textExplanation,
+ this.textExplanationIssue,
+ this.textExplanationOK});
this.contextKebapMenu.Name = "menuMain";
this.contextKebapMenu.RenderMode = System.Windows.Forms.ToolStripRenderMode.System;
- this.contextKebapMenu.Size = new System.Drawing.Size(259, 108);
+ this.contextKebapMenu.Size = new System.Drawing.Size(261, 251);
+ //
+ // textHeader
+ //
+ this.textHeader.BackColor = System.Drawing.Color.White;
+ this.textHeader.BorderStyle = System.Windows.Forms.BorderStyle.None;
+ this.textHeader.Font = new System.Drawing.Font("Segoe UI Variable Text Semibold", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.textHeader.ForeColor = System.Drawing.Color.Gray;
+ this.textHeader.Margin = new System.Windows.Forms.Padding(5, 5, 0, 10);
+ this.textHeader.Name = "textHeader";
+ this.textHeader.ReadOnly = true;
+ this.textHeader.Size = new System.Drawing.Size(100, 18);
+ this.textHeader.Text = "App-Info";
//
// menuAdvanced
//
this.menuAdvanced.Name = "menuAdvanced";
- this.menuAdvanced.Size = new System.Drawing.Size(258, 26);
+ this.menuAdvanced.Size = new System.Drawing.Size(260, 26);
this.menuAdvanced.Text = "Advanced mode";
this.menuAdvanced.Click += new System.EventHandler(this.menuAdvanced_Click);
//
- // menuIgnoreLowLevelP
+ // menuIgnoreLowLevelI
//
- this.menuIgnoreLowLevelP.Name = "menuIgnoreLowLevelP";
- this.menuIgnoreLowLevelP.Size = new System.Drawing.Size(258, 26);
- this.menuIgnoreLowLevelP.Text = "Ignore Low level problems";
- this.menuIgnoreLowLevelP.TextDirection = System.Windows.Forms.ToolStripTextDirection.Horizontal;
- this.menuIgnoreLowLevelP.Click += new System.EventHandler(this.menuIgnoreLowLevelP_Click);
+ this.menuIgnoreLowLevelI.Name = "menuIgnoreLowLevelI";
+ this.menuIgnoreLowLevelI.Size = new System.Drawing.Size(260, 26);
+ this.menuIgnoreLowLevelI.Text = "Ignore minor issues";
+ this.menuIgnoreLowLevelI.TextDirection = System.Windows.Forms.ToolStripTextDirection.Horizontal;
+ this.menuIgnoreLowLevelI.Click += new System.EventHandler(this.menuIgnoreLowLevelP_Click);
//
- // menuImportProfile
+ // cbProfiles
//
- this.menuImportProfile.Name = "menuImportProfile";
- this.menuImportProfile.Size = new System.Drawing.Size(258, 26);
- this.menuImportProfile.Text = "Import profile";
- this.menuImportProfile.Click += new System.EventHandler(this.menuImportProfile_Click);
+ this.cbProfiles.AutoToolTip = true;
+ this.cbProfiles.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
+ this.cbProfiles.FlatStyle = System.Windows.Forms.FlatStyle.System;
+ this.cbProfiles.Font = new System.Drawing.Font("Segoe UI Variable Text", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.cbProfiles.Name = "cbProfiles";
+ this.cbProfiles.Size = new System.Drawing.Size(200, 25);
+ //
+ // menuLoadProfile
+ //
+ this.menuLoadProfile.Font = new System.Drawing.Font("Segoe UI Variable Text Semibold", 12F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.menuLoadProfile.Name = "menuLoadProfile";
+ this.menuLoadProfile.Size = new System.Drawing.Size(260, 26);
+ this.menuLoadProfile.Text = "Load profile";
+ this.menuLoadProfile.Click += new System.EventHandler(this.menuLoadProfile_Click);
//
// menuExportProfile
//
this.menuExportProfile.Name = "menuExportProfile";
- this.menuExportProfile.Size = new System.Drawing.Size(258, 26);
+ this.menuExportProfile.Size = new System.Drawing.Size(260, 26);
this.menuExportProfile.Text = "Export profile";
this.menuExportProfile.Click += new System.EventHandler(this.menuExportProfile_Click);
//
+ // toolStripSeparator1
+ //
+ this.toolStripSeparator1.Name = "toolStripSeparator1";
+ this.toolStripSeparator1.Size = new System.Drawing.Size(257, 6);
+ //
+ // textExplanation
+ //
+ this.textExplanation.BackColor = System.Drawing.Color.White;
+ this.textExplanation.BorderStyle = System.Windows.Forms.BorderStyle.None;
+ this.textExplanation.Font = new System.Drawing.Font("Segoe UI Variable Text Semibold", 14.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.textExplanation.Margin = new System.Windows.Forms.Padding(5, 5, 1, 1);
+ this.textExplanation.Name = "textExplanation";
+ this.textExplanation.ReadOnly = true;
+ this.textExplanation.Size = new System.Drawing.Size(100, 26);
+ this.textExplanation.Text = "Explanation";
+ //
+ // textExplanationIssue
+ //
+ this.textExplanationIssue.BackColor = System.Drawing.Color.MediumVioletRed;
+ this.textExplanationIssue.BorderStyle = System.Windows.Forms.BorderStyle.None;
+ this.textExplanationIssue.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.textExplanationIssue.ForeColor = System.Drawing.Color.Transparent;
+ this.textExplanationIssue.Margin = new System.Windows.Forms.Padding(5, 1, 1, 1);
+ this.textExplanationIssue.Name = "textExplanationIssue";
+ this.textExplanationIssue.ReadOnly = true;
+ this.textExplanationIssue.Size = new System.Drawing.Size(190, 15);
+ this.textExplanationIssue.Text = "Color indicates a issue";
+ //
+ // textExplanationOK
+ //
+ this.textExplanationOK.BackColor = System.Drawing.Color.DarkGray;
+ this.textExplanationOK.BorderStyle = System.Windows.Forms.BorderStyle.None;
+ this.textExplanationOK.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.textExplanationOK.Margin = new System.Windows.Forms.Padding(5, 1, 1, 10);
+ this.textExplanationOK.Name = "textExplanationOK";
+ this.textExplanationOK.ReadOnly = true;
+ this.textExplanationOK.Size = new System.Drawing.Size(190, 15);
+ this.textExplanationOK.Text = "Color indicates that no action is needed";
+ //
// contextAppMenu
//
- this.contextAppMenu.BackColor = System.Drawing.SystemColors.Control;
+ this.contextAppMenu.BackColor = System.Drawing.Color.White;
this.contextAppMenu.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 15.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.contextAppMenu.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
this.menuFix,
@@ -396,7 +467,7 @@
//
// menuFixInfo
//
- this.menuFixInfo.BackColor = System.Drawing.SystemColors.Control;
+ this.menuFixInfo.BackColor = System.Drawing.Color.White;
this.menuFixInfo.BorderStyle = System.Windows.Forms.BorderStyle.None;
this.menuFixInfo.Enabled = false;
this.menuFixInfo.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
@@ -415,7 +486,7 @@
//
// menuRestoreInfo
//
- this.menuRestoreInfo.BackColor = System.Drawing.SystemColors.Control;
+ this.menuRestoreInfo.BackColor = System.Drawing.Color.White;
this.menuRestoreInfo.BorderStyle = System.Windows.Forms.BorderStyle.None;
this.menuRestoreInfo.Enabled = false;
this.menuRestoreInfo.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
@@ -446,9 +517,9 @@
this.AutoScaleDimensions = new System.Drawing.SizeF(96F, 96F);
this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Dpi;
this.BackColor = System.Drawing.Color.White;
- this.ClientSize = new System.Drawing.Size(1019, 801);
+ this.ClientSize = new System.Drawing.Size(430, 616);
this.Controls.Add(this.pnlForm);
- this.MinimumSize = new System.Drawing.Size(700, 700);
+ this.MinimumSize = new System.Drawing.Size(446, 655);
this.Name = "MainForm";
this.ShowIcon = false;
this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
@@ -458,6 +529,7 @@
this.pnlMain.ResumeLayout(false);
this.pnlMain.PerformLayout();
this.contextKebapMenu.ResumeLayout(false);
+ this.contextKebapMenu.PerformLayout();
this.contextAppMenu.ResumeLayout(false);
this.contextAppMenu.PerformLayout();
this.contextAppMenuOptions.ResumeLayout(false);
@@ -481,20 +553,26 @@
private System.Windows.Forms.ToolStripMenuItem menuAdvanced;
private System.Windows.Forms.Label label1;
private System.Windows.Forms.Button btnSettings;
- private System.Windows.Forms.ToolStripMenuItem menuIgnoreLowLevelP;
+ private System.Windows.Forms.ToolStripMenuItem menuIgnoreLowLevelI;
private System.Windows.Forms.Button btnAppOptions;
private System.Windows.Forms.ContextMenuStrip contextAppMenu;
private System.Windows.Forms.ToolStripMenuItem menuFix;
private System.Windows.Forms.ToolStripTextBox menuFixInfo;
private System.Windows.Forms.ToolStripMenuItem menuRestore;
private System.Windows.Forms.ToolStripTextBox menuRestoreInfo;
- private System.Windows.Forms.ToolStripMenuItem menuImportProfile;
+ private System.Windows.Forms.ToolStripMenuItem menuLoadProfile;
private System.Windows.Forms.LinkLabel lnkRunSetup;
private System.Windows.Forms.ToolStripMenuItem menuExportProfile;
private System.Windows.Forms.ContextMenuStrip contextAppMenuOptions;
private System.Windows.Forms.ToolStripMenuItem menuAppConfigure;
private System.Windows.Forms.Label lblAppOptionsFix;
- private System.Windows.Forms.LinkLabel lnkGitHubRepo;
+ private System.Windows.Forms.ToolStripSeparator toolStripSeparator1;
+ private System.Windows.Forms.ToolStripTextBox textExplanationIssue;
+ private System.Windows.Forms.ToolStripTextBox textExplanationOK;
+ private System.Windows.Forms.ToolStripComboBox cbProfiles;
+ private System.Windows.Forms.ToolStripTextBox textHeader;
+ private System.Windows.Forms.ToolStripTextBox textExplanation;
+ private System.Windows.Forms.Label lblOS;
}
}
diff --git a/src/BloatyNosy/Properties/AssemblyInfo.cs b/src/BloatyNosy/Properties/AssemblyInfo.cs
index bd46489..4d15946 100644
--- a/src/BloatyNosy/Properties/AssemblyInfo.cs
+++ b/src/BloatyNosy/Properties/AssemblyInfo.cs
@@ -31,5 +31,5 @@ using System.Runtime.InteropServices;
// Sie können alle Werte angeben oder Standardwerte für die Build- und Revisionsnummern verwenden,
// indem Sie "*" wie unten gezeigt eingeben:
// [assembly: AssemblyVersion("1.0.*")]
-[assembly: AssemblyVersion("0.40.0")]
-[assembly: AssemblyFileVersion("0.40.0")]
\ No newline at end of file
+[assembly: AssemblyVersion("0.51.0")]
+[assembly: AssemblyFileVersion("0.51.0")]
\ No newline at end of file
diff --git a/src/BloatyNosy/Resources/systemApps.txt b/src/BloatyNosy/Resources/systemApps.txt
index f7a9fd0..8d5b08b 100644
--- a/src/BloatyNosy/Resources/systemApps.txt
+++ b/src/BloatyNosy/Resources/systemApps.txt
@@ -26,7 +26,6 @@ Microsoft.Windows.AssignedAccessLockApp
Microsoft.Windows.CapturePicker
Microsoft.Windows.CloudExperienceHost
Microsoft.Windows.ContentDeliveryManager
-Microsoft.Windows.Cortana
Microsoft.Windows.NarratorQuickStart
Microsoft.Windows.OOBENetworkCaptivePortal
Microsoft.Windows.OOBENetworkConnectionFlow
diff --git a/src/BloatyNosy/Views/AboutPageView.Designer.cs b/src/BloatyNosy/Views/AboutPageView.Designer.cs
index 1a315bd..af79fd1 100644
--- a/src/BloatyNosy/Views/AboutPageView.Designer.cs
+++ b/src/BloatyNosy/Views/AboutPageView.Designer.cs
@@ -207,13 +207,17 @@
//
// btnAppMediaTweetIntent
//
- this.btnAppMediaTweetIntent.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 11.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
- this.btnAppMediaTweetIntent.Location = new System.Drawing.Point(67, 403);
+ this.btnAppMediaTweetIntent.BackColor = System.Drawing.Color.FromArgb(((int)(((byte)(64)))), ((int)(((byte)(64)))), ((int)(((byte)(64)))));
+ this.btnAppMediaTweetIntent.FlatAppearance.BorderColor = System.Drawing.Color.Lime;
+ this.btnAppMediaTweetIntent.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
+ this.btnAppMediaTweetIntent.Font = new System.Drawing.Font("Segoe UI Variable Display", 12F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.btnAppMediaTweetIntent.ForeColor = System.Drawing.Color.White;
+ this.btnAppMediaTweetIntent.Location = new System.Drawing.Point(66, 469);
this.btnAppMediaTweetIntent.Name = "btnAppMediaTweetIntent";
- this.btnAppMediaTweetIntent.Size = new System.Drawing.Size(149, 32);
+ this.btnAppMediaTweetIntent.Size = new System.Drawing.Size(302, 36);
this.btnAppMediaTweetIntent.TabIndex = 191;
- this.btnAppMediaTweetIntent.Text = "Tweet";
- this.btnAppMediaTweetIntent.UseVisualStyleBackColor = true;
+ this.btnAppMediaTweetIntent.Text = "Rate BloatyNosy on Microsoft Store";
+ this.btnAppMediaTweetIntent.UseVisualStyleBackColor = false;
this.btnAppMediaTweetIntent.Click += new System.EventHandler(this.btnAppMediaTweetIntent_Click);
//
// lnkUpdateAvailable
@@ -235,9 +239,9 @@
// btnHelp
//
this.btnHelp.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 11.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
- this.btnHelp.Location = new System.Drawing.Point(67, 451);
+ this.btnHelp.Location = new System.Drawing.Point(66, 418);
this.btnHelp.Name = "btnHelp";
- this.btnHelp.Size = new System.Drawing.Size(134, 32);
+ this.btnHelp.Size = new System.Drawing.Size(163, 32);
this.btnHelp.TabIndex = 196;
this.btnHelp.Text = "Help";
this.btnHelp.UseVisualStyleBackColor = true;
@@ -247,7 +251,6 @@
//
this.AutoScaleDimensions = new System.Drawing.SizeF(96F, 96F);
this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Dpi;
- this.AutoScroll = true;
this.BackColor = System.Drawing.Color.White;
this.Controls.Add(this.btnHelp);
this.Controls.Add(this.lnkUpdateAvailable);
diff --git a/src/BloatyNosy/Views/AboutPageView.cs b/src/BloatyNosy/Views/AboutPageView.cs
index 216a9e5..a43a58f 100644
--- a/src/BloatyNosy/Views/AboutPageView.cs
+++ b/src/BloatyNosy/Views/AboutPageView.cs
@@ -109,7 +109,7 @@ namespace BloatyNosy
=> Process.Start(HelperTool.Utils.Uri.URL_DONATE);
private void btnAppMediaTweetIntent_Click(object sender, System.EventArgs e)
- => Process.Start(HelperTool.Utils.TweetIntent);
+ => Process.Start("ms-windows-store://review/?ProductId=XPDCJG88N6FD16");
private void lnkUpdateAvailable_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
=> Utils.LaunchUri(Utils.Uri.URL_GITLATEST);
diff --git a/src/BloatyNosy/Views/AppsPageView.Designer.cs b/src/BloatyNosy/Views/AppsPageView.Designer.cs
index 5bacd82..ca25e71 100644
--- a/src/BloatyNosy/Views/AppsPageView.Designer.cs
+++ b/src/BloatyNosy/Views/AppsPageView.Designer.cs
@@ -32,7 +32,7 @@
System.Windows.Forms.ToolStripMenuItem menuAppsExport;
this.listRemove = new System.Windows.Forms.ListBox();
this.rtbStatus = new System.Windows.Forms.RichTextBox();
- this.btnRefresh = new System.Windows.Forms.Button();
+ this.btnAppOptions = new System.Windows.Forms.Button();
this.btnRestoreAll = new System.Windows.Forms.Button();
this.btnRestore = new System.Windows.Forms.Button();
this.btnMoveAll = new System.Windows.Forms.Button();
@@ -43,6 +43,7 @@
this.listApps = new System.Windows.Forms.ListBox();
this.checkAppsSystem = new System.Windows.Forms.CheckBox();
this.groupBin = new System.Windows.Forms.GroupBox();
+ this.picAppsPoster = new System.Windows.Forms.PictureBox();
this.lblAppsBinOptions = new System.Windows.Forms.LinkLabel();
this.groupInstalled = new System.Windows.Forms.GroupBox();
this.textSearch = new System.Windows.Forms.TextBox();
@@ -50,25 +51,29 @@
this.contextAppMenu = new System.Windows.Forms.ContextMenuStrip(this.components);
this.menuAppsImport = new System.Windows.Forms.ToolStripMenuItem();
this.menuAppsRemoveAll = new System.Windows.Forms.ToolStripMenuItem();
- this.toolStripSeparator1 = new System.Windows.Forms.ToolStripSeparator();
- this.menuSyncCommunity = new System.Windows.Forms.ToolStripMenuItem();
+ this.contextAppMenuOptions = new System.Windows.Forms.ContextMenuStrip(this.components);
+ this.menuAppsCommunity = new System.Windows.Forms.ToolStripMenuItem();
+ this.menuAppsHallOfShame = new System.Windows.Forms.ToolStripMenuItem();
+ this.toolStripSeparator2 = new System.Windows.Forms.ToolStripSeparator();
+ this.menuRefresh = new System.Windows.Forms.ToolStripMenuItem();
menuAppsExport = new System.Windows.Forms.ToolStripMenuItem();
this.groupBin.SuspendLayout();
+ ((System.ComponentModel.ISupportInitialize)(this.picAppsPoster)).BeginInit();
this.groupInstalled.SuspendLayout();
this.contextAppMenu.SuspendLayout();
+ this.contextAppMenuOptions.SuspendLayout();
this.SuspendLayout();
//
// menuAppsExport
//
menuAppsExport.Name = "menuAppsExport";
- menuAppsExport.Size = new System.Drawing.Size(337, 22);
+ menuAppsExport.Size = new System.Drawing.Size(193, 22);
menuAppsExport.Text = "Export bloatware in bin";
menuAppsExport.Click += new System.EventHandler(this.menuAppsExport_Click);
//
// listRemove
//
- this.listRemove.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
- | System.Windows.Forms.AnchorStyles.Left)
+ this.listRemove.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
| System.Windows.Forms.AnchorStyles.Right)));
this.listRemove.BackColor = System.Drawing.Color.White;
this.listRemove.BorderStyle = System.Windows.Forms.BorderStyle.None;
@@ -101,24 +106,25 @@
this.rtbStatus.Text = "";
this.rtbStatus.Visible = false;
//
- // btnRefresh
+ // btnAppOptions
//
- this.btnRefresh.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
- this.btnRefresh.BackColor = System.Drawing.Color.MediumVioletRed;
- this.btnRefresh.FlatAppearance.BorderColor = System.Drawing.Color.Orchid;
- this.btnRefresh.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
- this.btnRefresh.Font = new System.Drawing.Font("Segoe Fluent Icons", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
- this.btnRefresh.ForeColor = System.Drawing.Color.White;
- this.btnRefresh.Location = new System.Drawing.Point(977, 49);
- this.btnRefresh.Name = "btnRefresh";
- this.btnRefresh.Size = new System.Drawing.Size(31, 30);
- this.btnRefresh.TabIndex = 38;
- this.btnRefresh.Text = "Refresh";
- this.btnRefresh.UseVisualStyleBackColor = false;
- this.btnRefresh.Click += new System.EventHandler(this.btnRefresh_Click);
+ this.btnAppOptions.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
+ this.btnAppOptions.BackColor = System.Drawing.Color.MediumVioletRed;
+ this.btnAppOptions.FlatAppearance.BorderColor = System.Drawing.Color.Orchid;
+ this.btnAppOptions.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
+ this.btnAppOptions.Font = new System.Drawing.Font("Segoe Fluent Icons", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.btnAppOptions.ForeColor = System.Drawing.Color.White;
+ this.btnAppOptions.Location = new System.Drawing.Point(977, 49);
+ this.btnAppOptions.Name = "btnAppOptions";
+ this.btnAppOptions.Size = new System.Drawing.Size(31, 30);
+ this.btnAppOptions.TabIndex = 38;
+ this.btnAppOptions.Text = "...";
+ this.btnAppOptions.UseVisualStyleBackColor = false;
+ this.btnAppOptions.Click += new System.EventHandler(this.btnAppOptions_Click);
//
// btnRestoreAll
//
+ this.btnRestoreAll.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
this.btnRestoreAll.Font = new System.Drawing.Font("Segoe UI Variable Text", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.btnRestoreAll.ForeColor = System.Drawing.Color.Black;
this.btnRestoreAll.Location = new System.Drawing.Point(482, 313);
@@ -131,6 +137,7 @@
//
// btnRestore
//
+ this.btnRestore.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
this.btnRestore.Font = new System.Drawing.Font("Segoe UI Variable Text", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.btnRestore.ForeColor = System.Drawing.Color.Black;
this.btnRestore.Location = new System.Drawing.Point(482, 342);
@@ -143,6 +150,7 @@
//
// btnMoveAll
//
+ this.btnMoveAll.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
this.btnMoveAll.Font = new System.Drawing.Font("Segoe UI Variable Text", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.btnMoveAll.ForeColor = System.Drawing.Color.Black;
this.btnMoveAll.Location = new System.Drawing.Point(482, 201);
@@ -155,6 +163,7 @@
//
// btnMove
//
+ this.btnMove.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
this.btnMove.Font = new System.Drawing.Font("Segoe UI Variable Text", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.btnMove.ForeColor = System.Drawing.Color.Black;
this.btnMove.Location = new System.Drawing.Point(482, 230);
@@ -205,7 +214,7 @@
this.lblHeader.Name = "lblHeader";
this.lblHeader.Size = new System.Drawing.Size(960, 32);
this.lblHeader.TabIndex = 177;
- this.lblHeader.Text = "BloatFinder";
+ this.lblHeader.Text = "AppyTrash";
//
// listApps
//
@@ -241,12 +250,12 @@
//
// groupBin
//
- this.groupBin.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
- | System.Windows.Forms.AnchorStyles.Left)
+ this.groupBin.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
| System.Windows.Forms.AnchorStyles.Right)));
+ this.groupBin.Controls.Add(this.picAppsPoster);
+ this.groupBin.Controls.Add(this.rtbStatus);
this.groupBin.Controls.Add(this.lblAppsBinOptions);
this.groupBin.Controls.Add(this.listRemove);
- this.groupBin.Controls.Add(this.rtbStatus);
this.groupBin.Font = new System.Drawing.Font("Segoe UI Variable Text", 12F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.groupBin.ForeColor = System.Drawing.Color.DeepPink;
this.groupBin.Location = new System.Drawing.Point(609, 82);
@@ -256,17 +265,31 @@
this.groupBin.TabStop = false;
this.groupBin.Text = "Recycle bin";
//
+ // picAppsPoster
+ //
+ this.picAppsPoster.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
+ | System.Windows.Forms.AnchorStyles.Left)
+ | System.Windows.Forms.AnchorStyles.Right)));
+ this.picAppsPoster.ErrorImage = null;
+ this.picAppsPoster.InitialImage = null;
+ this.picAppsPoster.Location = new System.Drawing.Point(38, 105);
+ this.picAppsPoster.Name = "picAppsPoster";
+ this.picAppsPoster.Size = new System.Drawing.Size(331, 454);
+ this.picAppsPoster.SizeMode = System.Windows.Forms.PictureBoxSizeMode.Zoom;
+ this.picAppsPoster.TabIndex = 161;
+ this.picAppsPoster.TabStop = false;
+ this.picAppsPoster.Visible = false;
+ //
// lblAppsBinOptions
//
this.lblAppsBinOptions.ActiveLinkColor = System.Drawing.Color.MediumVioletRed;
this.lblAppsBinOptions.AutoEllipsis = true;
- this.lblAppsBinOptions.AutoSize = true;
- this.lblAppsBinOptions.Font = new System.Drawing.Font("Segoe UI Variable Text Semibold", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.lblAppsBinOptions.Font = new System.Drawing.Font("Segoe UI Variable Text", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.lblAppsBinOptions.LinkBehavior = System.Windows.Forms.LinkBehavior.HoverUnderline;
- this.lblAppsBinOptions.LinkColor = System.Drawing.Color.Black;
+ this.lblAppsBinOptions.LinkColor = System.Drawing.Color.Gray;
this.lblAppsBinOptions.Location = new System.Drawing.Point(8, 36);
this.lblAppsBinOptions.Name = "lblAppsBinOptions";
- this.lblAppsBinOptions.Size = new System.Drawing.Size(318, 16);
+ this.lblAppsBinOptions.Size = new System.Drawing.Size(361, 16);
this.lblAppsBinOptions.TabIndex = 159;
this.lblAppsBinOptions.TabStop = true;
this.lblAppsBinOptions.Text = "Move the apps you want to uninstall here or import via file.";
@@ -275,8 +298,9 @@
//
// groupInstalled
//
- this.groupInstalled.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
- | System.Windows.Forms.AnchorStyles.Left)));
+ this.groupInstalled.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
+ | System.Windows.Forms.AnchorStyles.Left)
+ | System.Windows.Forms.AnchorStyles.Right)));
this.groupInstalled.Controls.Add(this.listApps);
this.groupInstalled.Font = new System.Drawing.Font("Segoe UI Variable Text", 12F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.groupInstalled.ForeColor = System.Drawing.Color.Violet;
@@ -289,6 +313,7 @@
//
// textSearch
//
+ this.textSearch.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
this.textSearch.BackColor = System.Drawing.Color.WhiteSmoke;
this.textSearch.Font = new System.Drawing.Font("Segoe UI Variable Text", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.textSearch.ForeColor = System.Drawing.Color.Gray;
@@ -322,39 +347,65 @@
this.contextAppMenu.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
this.menuAppsImport,
menuAppsExport,
- this.menuAppsRemoveAll,
- this.toolStripSeparator1,
- this.menuSyncCommunity});
+ this.menuAppsRemoveAll});
this.contextAppMenu.Name = "menuMain";
this.contextAppMenu.RenderMode = System.Windows.Forms.ToolStripRenderMode.System;
- this.contextAppMenu.Size = new System.Drawing.Size(338, 98);
+ this.contextAppMenu.Size = new System.Drawing.Size(194, 70);
this.contextAppMenu.Text = "Info";
//
// menuAppsImport
//
this.menuAppsImport.Name = "menuAppsImport";
- this.menuAppsImport.Size = new System.Drawing.Size(337, 22);
+ this.menuAppsImport.Size = new System.Drawing.Size(193, 22);
this.menuAppsImport.Text = "Import bloatware list";
this.menuAppsImport.Click += new System.EventHandler(this.menuAppsImport_Click);
//
// menuAppsRemoveAll
//
this.menuAppsRemoveAll.Name = "menuAppsRemoveAll";
- this.menuAppsRemoveAll.Size = new System.Drawing.Size(337, 22);
+ this.menuAppsRemoveAll.Size = new System.Drawing.Size(193, 22);
this.menuAppsRemoveAll.Text = "Uninstall all apps";
this.menuAppsRemoveAll.Click += new System.EventHandler(this.menuAppsRemoveAll_Click);
//
- // toolStripSeparator1
+ // contextAppMenuOptions
//
- this.toolStripSeparator1.Name = "toolStripSeparator1";
- this.toolStripSeparator1.Size = new System.Drawing.Size(334, 6);
+ this.contextAppMenuOptions.BackColor = System.Drawing.Color.WhiteSmoke;
+ this.contextAppMenuOptions.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.contextAppMenuOptions.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
+ this.menuAppsCommunity,
+ this.menuAppsHallOfShame,
+ this.toolStripSeparator2,
+ this.menuRefresh});
+ this.contextAppMenuOptions.Name = "menuMain";
+ this.contextAppMenuOptions.RenderMode = System.Windows.Forms.ToolStripRenderMode.System;
+ this.contextAppMenuOptions.Size = new System.Drawing.Size(368, 76);
+ this.contextAppMenuOptions.Text = "Info";
//
- // menuSyncCommunity
+ // menuAppsCommunity
//
- this.menuSyncCommunity.Name = "menuSyncCommunity";
- this.menuSyncCommunity.Size = new System.Drawing.Size(337, 22);
- this.menuSyncCommunity.Text = "Sync bloatware with community list (Slasher Mode)";
- this.menuSyncCommunity.Click += new System.EventHandler(this.menuSyncCommunity_Click);
+ this.menuAppsCommunity.Name = "menuAppsCommunity";
+ this.menuAppsCommunity.Size = new System.Drawing.Size(367, 22);
+ this.menuAppsCommunity.Text = "Add bloatware rated by community to recycle bin";
+ this.menuAppsCommunity.Click += new System.EventHandler(this.menuAppsCommunity_Click);
+ //
+ // menuAppsHallOfShame
+ //
+ this.menuAppsHallOfShame.Name = "menuAppsHallOfShame";
+ this.menuAppsHallOfShame.Size = new System.Drawing.Size(367, 22);
+ this.menuAppsHallOfShame.Text = "Add the 10 most hated apps of Windows 11 to recycle bin";
+ this.menuAppsHallOfShame.Click += new System.EventHandler(this.menuAppsHallOfShame_Click);
+ //
+ // toolStripSeparator2
+ //
+ this.toolStripSeparator2.Name = "toolStripSeparator2";
+ this.toolStripSeparator2.Size = new System.Drawing.Size(364, 6);
+ //
+ // menuRefresh
+ //
+ this.menuRefresh.Name = "menuRefresh";
+ this.menuRefresh.Size = new System.Drawing.Size(367, 22);
+ this.menuRefresh.Text = "Refresh";
+ this.menuRefresh.Click += new System.EventHandler(this.menuRefresh_Click);
//
// AppsPageView
//
@@ -369,7 +420,7 @@
this.Controls.Add(this.btnBack);
this.Controls.Add(this.btnUninstall);
this.Controls.Add(this.groupBin);
- this.Controls.Add(this.btnRefresh);
+ this.Controls.Add(this.btnAppOptions);
this.Controls.Add(this.btnRestoreAll);
this.Controls.Add(this.groupInstalled);
this.Controls.Add(this.btnRestore);
@@ -378,9 +429,10 @@
this.Name = "AppsPageView";
this.Size = new System.Drawing.Size(1054, 795);
this.groupBin.ResumeLayout(false);
- this.groupBin.PerformLayout();
+ ((System.ComponentModel.ISupportInitialize)(this.picAppsPoster)).EndInit();
this.groupInstalled.ResumeLayout(false);
this.contextAppMenu.ResumeLayout(false);
+ this.contextAppMenuOptions.ResumeLayout(false);
this.ResumeLayout(false);
this.PerformLayout();
@@ -388,7 +440,7 @@
#endregion
private System.Windows.Forms.ListBox listRemove;
- private System.Windows.Forms.Button btnRefresh;
+ private System.Windows.Forms.Button btnAppOptions;
private System.Windows.Forms.Button btnRestoreAll;
private System.Windows.Forms.Button btnRestore;
private System.Windows.Forms.Button btnMoveAll;
@@ -407,7 +459,11 @@
private System.Windows.Forms.ContextMenuStrip contextAppMenu;
private System.Windows.Forms.ToolStripMenuItem menuAppsImport;
private System.Windows.Forms.ToolStripMenuItem menuAppsRemoveAll;
- private System.Windows.Forms.ToolStripSeparator toolStripSeparator1;
- private System.Windows.Forms.ToolStripMenuItem menuSyncCommunity;
+ private System.Windows.Forms.ContextMenuStrip contextAppMenuOptions;
+ private System.Windows.Forms.ToolStripMenuItem menuAppsCommunity;
+ private System.Windows.Forms.ToolStripMenuItem menuAppsHallOfShame;
+ private System.Windows.Forms.ToolStripSeparator toolStripSeparator2;
+ private System.Windows.Forms.ToolStripMenuItem menuRefresh;
+ private System.Windows.Forms.PictureBox picAppsPoster;
}
}
diff --git a/src/BloatyNosy/Views/AppsPageView.cs b/src/BloatyNosy/Views/AppsPageView.cs
index c9b5f2b..163d35c 100644
--- a/src/BloatyNosy/Views/AppsPageView.cs
+++ b/src/BloatyNosy/Views/AppsPageView.cs
@@ -39,7 +39,10 @@ namespace BloatyNosy
btnHMenu.Text = "\uE700";
btnBack.Text = "\uE72B";
- btnRefresh.Text = "\uE72C";
+ btnAppOptions.Text = "\uE972";
+
+ if (!HelperTool.Utils.IsInet()) picAppsPoster.Visible = false;
+ else picAppsPoster.ImageLocation = "https://github.com/builtbybel/ThisIsWin11/blob/main/assets/pages/page-apps.png?raw=true";
}
private void InitializeApps()
@@ -131,15 +134,21 @@ namespace BloatyNosy
if (listRemove.Items.Count == 0)
{
- rtbStatus.Visible = true;
+
lblAppsBinOptions.Visible = true;
+ picAppsPoster.Visible = true;
+
+ rtbStatus.Visible = true;
listRemove.Visible = false;
+
}
else
{
- listRemove.Visible = true;
lblAppsBinOptions.Visible = false;
+ picAppsPoster.Visible = false;
+
rtbStatus.Visible = false;
+ listRemove.Visible = true;
}
if (installed == 0)
@@ -161,16 +170,6 @@ namespace BloatyNosy
true;
}
- private void btnRefresh_Click(object sender, EventArgs e)
- {
- listApps.Items.Clear();
- listRemove.Items.Clear();
- removeAppsList.Clear();
-
- InitializeAppsSystem();
- InitializeApps();
- }
-
private void btnRestoreAll_Click(object sender, EventArgs e)
{
foreach (var item in listRemove.Items)
@@ -289,7 +288,7 @@ namespace BloatyNosy
"as these apps are needed for the Windows 11 Experience and for other programs. If you try, you’ll see an error message saying the removal failed.";
}
- btnRefresh.PerformClick();
+ menuRefresh.PerformClick();
btnUninstall.Enabled = true;
rtbStatus.Text = message + Environment.NewLine;
@@ -403,12 +402,12 @@ namespace BloatyNosy
}
}
- private void menuSyncCommunity_Click(object sender, EventArgs e)
+ private void menuAppsCommunity_Click(object sender, EventArgs e)
{
if (MessageBox.Show("This will add all the annoying bloatware apps, " +
- "pre-installed on Windows 11 including some apps your PC manufacturer included to the removal list." +
- "\r\n\nMost of these apps are garbage, but if you find important stuff on the list just remove it " +
- "from the right box before hitting \"Uninstall\".", this.Text, MessageBoxButtons.YesNo, MessageBoxIcon.Information) == DialogResult.Yes)
+ "pre-installed on Windows 11 including some apps your PC manufacturer included to the removal list." +
+ "\r\n\nMost of these apps are garbage, but if you find important stuff on the list just remove it " +
+ "from the right box before hitting \"Uninstall\".", this.Text, MessageBoxButtons.YesNo, MessageBoxIcon.Information) == DialogResult.Yes)
{
var apps = BloatwareList.GetList();
listRemove.Visible = true;
@@ -422,5 +421,34 @@ namespace BloatyNosy
RefreshApps();
}
}
+
+ private void menuAppsHallOfShame_Click(object sender, EventArgs e)
+ {
+ var apps = BloatwareHallOfShame.GetList();
+ listRemove.Visible = true;
+
+ foreach (string app in apps)
+ {
+ listRemove.Items.Add(app);
+ }
+
+ InitializeApps();
+ RefreshApps();
+ }
+
+ private void btnAppOptions_Click(object sender, EventArgs e)
+ => this.contextAppMenuOptions.Show(Cursor.Position.X, Cursor.Position.Y);
+
+ private void menuRefresh_Click(object sender, EventArgs e)
+ {
+ listApps.Items.Clear();
+ listRemove.Items.Clear();
+ removeAppsList.Clear();
+
+ InitializeAppsSystem();
+ InitializeApps();
+
+ picAppsPoster.Visible = false;
+ }
}
}
\ No newline at end of file
diff --git a/src/BloatyNosy/Views/AppsPageView.resx b/src/BloatyNosy/Views/AppsPageView.resx
index 936580f..608ba94 100644
--- a/src/BloatyNosy/Views/AppsPageView.resx
+++ b/src/BloatyNosy/Views/AppsPageView.resx
@@ -123,4 +123,7 @@
17, 17
+
+ 172, 17
+
\ No newline at end of file
diff --git a/src/BloatyNosy/Views/ModsPageView.Designer.cs b/src/BloatyNosy/Views/ModsPageView.Designer.cs
index 882a4d6..3debfa2 100644
--- a/src/BloatyNosy/Views/ModsPageView.Designer.cs
+++ b/src/BloatyNosy/Views/ModsPageView.Designer.cs
@@ -32,6 +32,7 @@
System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(ModsPageView));
this.contextAppMenu = new System.Windows.Forms.ContextMenuStrip(this.components);
this.menuModEdit = new System.Windows.Forms.ToolStripMenuItem();
+ this.menuModOpenDir = new System.Windows.Forms.ToolStripMenuItem();
this.pnlForm = new System.Windows.Forms.Panel();
this.pnlMain = new System.Windows.Forms.Panel();
this.lblStatus = new System.Windows.Forms.Label();
@@ -64,19 +65,27 @@
this.contextAppMenu.BackColor = System.Drawing.Color.WhiteSmoke;
this.contextAppMenu.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.contextAppMenu.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
- this.menuModEdit});
+ this.menuModEdit,
+ this.menuModOpenDir});
this.contextAppMenu.Name = "menuMain";
this.contextAppMenu.RenderMode = System.Windows.Forms.ToolStripRenderMode.System;
- this.contextAppMenu.Size = new System.Drawing.Size(122, 26);
+ this.contextAppMenu.Size = new System.Drawing.Size(181, 70);
this.contextAppMenu.Text = "Info";
//
// menuModEdit
//
this.menuModEdit.Name = "menuModEdit";
- this.menuModEdit.Size = new System.Drawing.Size(121, 22);
+ this.menuModEdit.Size = new System.Drawing.Size(180, 22);
this.menuModEdit.Text = "Edit Mod";
this.menuModEdit.Click += new System.EventHandler(this.menuModEdit_Click);
//
+ // menuModOpenDir
+ //
+ this.menuModOpenDir.Name = "menuModOpenDir";
+ this.menuModOpenDir.Size = new System.Drawing.Size(180, 22);
+ this.menuModOpenDir.Text = "Open Mods Folder";
+ this.menuModOpenDir.Click += new System.EventHandler(this.menuModOpenDir_Click);
+ //
// pnlForm
//
this.pnlForm.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
@@ -386,5 +395,6 @@
private System.Windows.Forms.Button btnBack;
public System.Windows.Forms.LinkLabel lnkExploreMods;
private System.Windows.Forms.Label lblStatus;
+ private System.Windows.Forms.ToolStripMenuItem menuModOpenDir;
}
}
diff --git a/src/BloatyNosy/Views/ModsPageView.cs b/src/BloatyNosy/Views/ModsPageView.cs
index d8551b4..90da442 100644
--- a/src/BloatyNosy/Views/ModsPageView.cs
+++ b/src/BloatyNosy/Views/ModsPageView.cs
@@ -249,5 +249,11 @@ namespace BloatyNosy
mainForm.pnlForm.Controls.Clear();
if (mainForm.INavPage != null) mainForm.pnlForm.Controls.Add(mainForm.INavPage);
}
+
+ private void menuModOpenDir_Click(object sender, EventArgs e)
+ {
+ Process.Start(new ProcessStartInfo("explorer.exe", HelperTool.Utils.Data.ModsRootDir) { UseShellExecute = true });
+ }
+
}
}
\ No newline at end of file
diff --git a/src/BloatyNosy/Views/PackagesPageView.cs b/src/BloatyNosy/Views/PackagesPageView.cs
index 631ef71..15ba1af 100644
--- a/src/BloatyNosy/Views/PackagesPageView.cs
+++ b/src/BloatyNosy/Views/PackagesPageView.cs
@@ -154,7 +154,7 @@ namespace BloatyNosy
StartInfo = new ProcessStartInfo
{
FileName = HelperTool.Utils.Paths.ShellPS,
- Arguments = "winget install --id " + packageid + " --accept-source-agreements --accept-package-agreements",
+ Arguments = "winget install --id " + packageid + " --silent --accept-source-agreements --accept-package-agreements",
UseShellExecute = false,
CreateNoWindow = true,
}
diff --git a/src/BloatyNosy/Views/SetupPageView.Designer.cs b/src/BloatyNosy/Views/SetupPageView.Designer.cs
index d0a3c3c..bdf4e6d 100644
--- a/src/BloatyNosy/Views/SetupPageView.Designer.cs
+++ b/src/BloatyNosy/Views/SetupPageView.Designer.cs
@@ -76,7 +76,7 @@
this.btnHome.FlatStyle = System.Windows.Forms.FlatStyle.System;
this.btnHome.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.btnHome.ForeColor = System.Drawing.Color.Black;
- this.btnHome.Location = new System.Drawing.Point(669, 728);
+ this.btnHome.Location = new System.Drawing.Point(669, 750);
this.btnHome.Name = "btnHome";
this.btnHome.Size = new System.Drawing.Size(89, 29);
this.btnHome.TabIndex = 182;
@@ -91,7 +91,7 @@
this.btnNext.FlatStyle = System.Windows.Forms.FlatStyle.System;
this.btnNext.Font = new System.Drawing.Font("Segoe UI Variable Text", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.btnNext.ForeColor = System.Drawing.Color.White;
- this.btnNext.Location = new System.Drawing.Point(859, 728);
+ this.btnNext.Location = new System.Drawing.Point(859, 750);
this.btnNext.Name = "btnNext";
this.btnNext.Size = new System.Drawing.Size(89, 29);
this.btnNext.TabIndex = 183;
@@ -106,7 +106,7 @@
this.btnPrev.FlatStyle = System.Windows.Forms.FlatStyle.System;
this.btnPrev.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.btnPrev.ForeColor = System.Drawing.Color.Black;
- this.btnPrev.Location = new System.Drawing.Point(764, 728);
+ this.btnPrev.Location = new System.Drawing.Point(764, 750);
this.btnPrev.Name = "btnPrev";
this.btnPrev.Size = new System.Drawing.Size(89, 29);
this.btnPrev.TabIndex = 184;
@@ -120,7 +120,7 @@
this.cbTable.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
this.cbTable.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.cbTable.FormattingEnabled = true;
- this.cbTable.Location = new System.Drawing.Point(102, 734);
+ this.cbTable.Location = new System.Drawing.Point(55, 756);
this.cbTable.Name = "cbTable";
this.cbTable.Size = new System.Drawing.Size(121, 23);
this.cbTable.TabIndex = 185;
@@ -172,7 +172,7 @@
this.lnkCustomize.Font = new System.Drawing.Font("Segoe UI Variable Text Semibold", 11.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.lnkCustomize.LinkBehavior = System.Windows.Forms.LinkBehavior.HoverUnderline;
this.lnkCustomize.LinkColor = System.Drawing.Color.DeepPink;
- this.lnkCustomize.Location = new System.Drawing.Point(553, 493);
+ this.lnkCustomize.Location = new System.Drawing.Point(554, 481);
this.lnkCustomize.Name = "lnkCustomize";
this.lnkCustomize.Size = new System.Drawing.Size(177, 20);
this.lnkCustomize.TabIndex = 191;
@@ -187,7 +187,7 @@
this.lnkConfigure.Font = new System.Drawing.Font("Segoe UI Variable Text Semiligh", 11.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.lnkConfigure.LinkBehavior = System.Windows.Forms.LinkBehavior.HoverUnderline;
this.lnkConfigure.LinkColor = System.Drawing.Color.DeepPink;
- this.lnkConfigure.Location = new System.Drawing.Point(553, 528);
+ this.lnkConfigure.Location = new System.Drawing.Point(554, 516);
this.lnkConfigure.Name = "lnkConfigure";
this.lnkConfigure.Size = new System.Drawing.Size(126, 20);
this.lnkConfigure.TabIndex = 192;
diff --git a/src/BloatyNosy/app.manifest b/src/BloatyNosy/app.manifest
index 24ca809..f8a144b 100644
--- a/src/BloatyNosy/app.manifest
+++ b/src/BloatyNosy/app.manifest
@@ -16,7 +16,7 @@
Entfernen Sie dieses Element, wenn diese Virtualisierung aus Gründen der Abwärtskompatibilität
für die Anwendung erforderlich ist.
-->
-
+
diff --git a/src/BloatyNosy/MainForm.cs b/src/BloatyNosy/MainForm.cs
index e4e7d25..3f1012d 100644
--- a/src/BloatyNosy/MainForm.cs
+++ b/src/BloatyNosy/MainForm.cs
@@ -3,7 +3,6 @@ using Features.Feature;
using HelperTool;
using System;
using System.Collections.Generic;
-using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Linq;
@@ -28,6 +27,7 @@ namespace BloatyNosy
{
this.AddDefaultFeatures();
this.AddMoreApps();
+ this.Piglet1();
this.SetStyle();
}
@@ -37,7 +37,7 @@ namespace BloatyNosy
btnAppOptions.Text = "\uE70D";
btnKebapMenu.Text = "\u22ee";
btnSettings.Text = "\uE713";
- btnAnalyze.Text += OsHelper.GetVersion();
+ lblOS.Text += OsHelper.GetVersion();
BackColor =
tvwFeatures.BackColor =
@@ -45,6 +45,9 @@ namespace BloatyNosy
Color.FromArgb(244, 241, 249);
logger.SetTarget(rtbLog); // Log messages to target richLog
INavPage = pnlForm.Controls[0]; // Set default NavPage
+
+ this.Location = new Point((Screen.PrimaryScreen.WorkingArea.Width - this.Width) / 2,
+ (Screen.PrimaryScreen.WorkingArea.Height - this.Height));
}
public void SetView(Control View)
@@ -62,11 +65,33 @@ namespace BloatyNosy
private void AddMoreApps()
{
- cmbTools.Items.Add("InstaPackage");
- cmbTools.Items.Add("BloatFinder");
+ cmbTools.Items.Add("AppyTrash");
cmbTools.Items.Add("WinModder");
cmbTools.Items.Insert(0, "More Apps");
cmbTools.SelectedIndex = 0;
+ if (File.Exists(HelperTool.Utils.Paths.ProgramFiles + @"\Builtbybel\BloatyNosy\BloatyNosy.exe"))
+ {
+ /* if (MessageBox.Show("InstaPackage app is not available in the Microsoft Store version of the app because, " +
+ "according to Microsoft, it triggers conflicts with the store policies.\n\n" +
+ "Do you want to download the open source version hosted on GitHub?", "Not available in Store", MessageBoxButtons.YesNo, MessageBoxIcon.Information, MessageBoxDefaultButton.Button2) == DialogResult.Yes)
+ Process.Start(HelperTool.Utils.Uri.URL_GITREPO);*/
+ }
+ else
+ cmbTools.Items.Add("InstaPackage");
+ }
+
+ private void Piglet1()
+ {
+ cbProfiles.Items.Clear();
+ cbProfiles.Items.Insert(0, "Select profile");
+ cbProfiles.SelectedIndex = 0;
+
+ try
+ {
+ string[] files = Directory.GetFiles(HelperTool.Utils.Data.DataRootDir, "*.bloos");
+ cbProfiles.Items.AddRange(files.Select((string filePath) => Path.GetFileNameWithoutExtension(filePath)).ToArray());
+ }
+ catch { cbProfiles.Text = "No profiles found."; }
}
///
@@ -77,18 +102,18 @@ namespace BloatyNosy
private void cmbTools_SelectedIndexChanged(object sender, EventArgs e)
{
string message = Convert.ToString(cmbTools.SelectedItem);
- string[] keys = new string[] { "Insta", "Bloat", "Mod" };
+ string[] keys = new string[] { "Package", "Trash", "Mod" };
string sKeyResult = keys.FirstOrDefault(s => message.Contains(s));
switch (sKeyResult)
{
- case "Insta":
+ case "Package":
this.SetView(new PackagesPageView()); // Packages > InstaPackages view
break;
- case "Bloat":
- this.SetView(new AppsPageView()); // In-box apps > BloatFinder view
+ case "Trash":
+ this.SetView(new AppsPageView()); // In-box apps > AppyTrash view
break;
case "Mod":
@@ -112,12 +137,13 @@ namespace BloatyNosy
tvwFeatures.BeginUpdate();
// Root node
- TreeNode root = new TreeNode("Problems to be checked ")
+ TreeNode root = new TreeNode("Potential issues ")
{
Checked = true,
};
TreeNode browser = new TreeNode("Browser", new TreeNode[] {
+ new FeatureNode(new Features.Feature.Browser.EdgeBingAIButton()),
new FeatureNode(new Features.Feature.Browser.ChromeTelemetry()),
new FeatureNode(new Features.Feature.Browser.FirefoxTelemetry()),
})
@@ -188,10 +214,10 @@ namespace BloatyNosy
new FeatureNode(new Features.Feature.Privacy.Advertising()),
new FeatureNode(new Features.Feature.Privacy.Feedback()),
new FeatureNode(new Features.Feature.Privacy.SuggestedContent()),
- new FeatureNode(new Features.Feature.Privacy.Biometrics()),
new FeatureNode(new Features.Feature.Privacy.AppsAutoInstall()),
new FeatureNode(new Features.Feature.Privacy.WindowsTips()),
new FeatureNode(new Features.Feature.Privacy.TailoredExperiences()),
+ new FeatureNode(new Features.Feature.Privacy.BackgroundApps()),
})
{
Checked = true
@@ -249,7 +275,7 @@ namespace BloatyNosy
bool shouldPerform = await analyzeTask;
lnkSubHeader.Text = "Check " + feature.ID();
- if (menuIgnoreLowLevelP.Checked == true)
+ if (menuIgnoreLowLevelI.Checked == true)
if (shouldPerform & !node.Text.Contains("LOW"))
{
logger.Log("Problem on " + node.Parent.Text + ": " + feature.ID());
@@ -318,6 +344,16 @@ namespace BloatyNosy
return selectedFeatures;
}
+ private void ResetColorNode(TreeNodeCollection nodes, Color Color)
+ {
+ foreach (System.Windows.Forms.TreeNode child in nodes)
+ {
+ child.BackColor = Color;
+ if (child.Nodes != null && child.Nodes.Count > 0)
+ ResetColorNode(child.Nodes, Color);
+ }
+ }
+
private void Reset()
{
progression = 0;
@@ -438,7 +474,7 @@ namespace BloatyNosy
private void menuIgnoreLowLevelP_Click(object sender, EventArgs e)
{
- menuIgnoreLowLevelP.Checked = !(menuIgnoreLowLevelP.Checked);
+ menuIgnoreLowLevelI.Checked = !(menuIgnoreLowLevelI.Checked);
SelectFeatureNodes(tvwFeatures.Nodes, true);
}
@@ -457,40 +493,42 @@ namespace BloatyNosy
private void lblAppOptionsFix_Click(object sender, EventArgs e)
=> btnAppOptions.PerformClick();
- private void lnkGitHubRepo_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
- => Process.Start(Utils.Uri.URL_GITREPO);
- private void menuImportProfile_Click(object sender, EventArgs e)
+ private void lblOS_Click(object sender, EventArgs e)
+ => btnAnalyze.PerformClick();
+
+ private void menuLoadProfile_Click(object sender, EventArgs e)
{
- OpenFileDialog f = new OpenFileDialog();
- f.InitialDirectory = HelperTool.Utils.Data.DataRootDir;
- f.Filter = "BloatyNosy files (*.bloos)|*.bloos|ThisIsWin11 files (*.tiw1)|*.tiw1";
+ string filePath = HelperTool.Utils.Data.DataRootDir + "\\" + cbProfiles.Text + ".bloos";
- if (f.ShowDialog() == DialogResult.OK)
+ ResetColorNode(tvwFeatures.Nodes, Color.FromArgb(244, 241, 249));
+ SelectFeatureNodes(tvwFeatures.Nodes, false);
+ tvwFeatures.ExpandAll();
+ tvwFeatures.Nodes[0].EnsureVisible();
+
+ try
{
- SelectFeatureNodes(tvwFeatures.Nodes, false);
- tvwFeatures.ExpandAll();
- tvwFeatures.Nodes[0].EnsureVisible();
- menuAdvanced.PerformClick();
-
- using (StreamReader reader = new StreamReader(f.OpenFile()))
+ using (StreamReader reader = new StreamReader(filePath))
{
while (!reader.EndOfStream)
{
string line = reader.ReadLine();
- foreach (TreeNode treeNode in tvwFeatures.Nodes.All())
+ foreach (System.Windows.Forms.TreeNode treeNode in tvwFeatures.Nodes.All())
{
if (treeNode.Text.Contains(line))
{
treeNode.BackColor = Color.Yellow;
- treeNode.Text += "\x20" + "(" + Path.GetFileNameWithoutExtension(f.FileName) + ")";
treeNode.Checked = true;
+ tvwFeatures.SelectedNode = treeNode;
}
}
}
-
- MessageBox.Show("Profile has been successfully imported.\n\nWe have highlighted the configuration that would be enabled (no changes are done yet).", this.Text, MessageBoxButtons.OK, MessageBoxIcon.Information);
+ if (new FileInfo(filePath).Length == 0) logger.Log("- Empty configuration loaded.");
}
+
+ btnAnalyze.PerformClick();
+ logger.Log($"[{cbProfiles.Text} has been successfully loaded].\nWe have highlighted the configuration that would be enabled (no changes are done yet).");
}
+ catch { { MessageBox.Show("No profile selected."); } }
}
private void menuExportProfile_Click(object sender, EventArgs e)
@@ -538,7 +576,7 @@ namespace BloatyNosy
switch (tn.Text)
{
case "*[HIGH] Search and remove pre-installed bloatware apps automatically (Right-click to remove bloatware manually)":
- this.SetView(new AppsPageView()); // In-box apps > BloatFinder view
+ this.SetView(new AppsPageView()); // In-box apps > AppyTrash view
break;
default: